@@ -33,8 +33,6 @@ import java.util.Locale;
 
 import javax.swing.*;
 
-import org.jvnet.lafwidget.combo.AutoCompletionMatcher;
-import org.jvnet.lafwidget.combo.DefaultAutoCompletionMatcher;
 import org.jvnet.lafwidget.preview.DefaultPreviewPainter;
 import org.jvnet.lafwidget.preview.PreviewPainter;
 import org.jvnet.lafwidget.tabbed.*;
@@ -47,74 +45,7 @@ import org.jvnet.lafwidget.utils.LafConstants;
  * 
  * @author Kirill Grouchnikov
  */
-public interface LafWidget {
-	/**
-	 * <p>
-	 * Client property name for specifying that the editable combobox can accept
-	 * only entries from the model. This property can be set either on a single
-	 * combobox or globally on {@link UIManager}. The value in both cases
-	 * should be either {@link Boolean#TRUE} or {@link Boolean#FALSE}.
-	 * </p>
-	 * 
-	 * <p>
-	 * Here is an example of editable combobox that accepts model-entries only:
-	 * </p>
-	 * 
-	 * <code>
-	 * final JComboBox comboCompletionModelOnlyTest = new JComboBox(<br>
-	 * &nbsp;&nbsp;new Object[] { "Ester", "Jordi", "Jordina", "Jorge", "Sergi" });<br>
-	 * comboCompletionModelOnlyTest.setEditable(true);<br>
-	 * comboCompletionModelOnlyTest.putClientProperty(<br>
-	 * &nbsp;&nbsp;LafWidget.COMBO_BOX_USE_MODEL_ONLY, Boolean.TRUE);
-	 * </code>
-	 * 
-	 * @see #COMBO_BOX_AUTOCOMPLETION_MATCHER
-	 * @see #COMBO_BOX_NO_AUTOCOMPLETION
-	 */
-	public final static String COMBO_BOX_USE_MODEL_ONLY = "lafwidgets.comboboxUseModelOnly";
-
-	/**
-	 * <p>
-	 * Client property name for specifying that the editable combobox has no
-	 * auto completion. This property can be set either on a single combobox or
-	 * globally on {@link UIManager}. The value in both cases should be either
-	 * {@link Boolean#TRUE} or {@link Boolean#FALSE}. By default, all editable
-	 * comboboxes have auto-completion.
-	 * </p>
-	 * 
-	 * <p>
-	 * Here is an example of editable combobox that has no auto-completion:
-	 * </p>
-	 * 
-	 * <code>
-	 * final JComboBox comboNoAutoCompletion = new JComboBox(<br>
-	 * &nbsp;&nbsp;new Object[] { "Ester", "Jordi", "Jordina", "Jorge", "Sergi" });<br>
-	 * comboCompletionModelOnlyTest.setEditable(true);<br>
-	 * comboCompletionModelOnlyTest.putClientProperty(<br>
-	 * &nbsp;&nbsp;LafWidget.COMBO_BOX_NO_AUTOCOMPLETION, Boolean.TRUE);
-	 * </code>
-	 * 
-	 * @see #COMBO_BOX_AUTOCOMPLETION_MATCHER
-	 * @see #COMBO_BOX_USE_MODEL_ONLY
-	 */
-	public final static String COMBO_BOX_NO_AUTOCOMPLETION = "lafwidgets.comboboxNoAutoCompletion";
-
-	/**
-	 * <p>
-	 * Client property name for specifying the auto-completion matcher for
-	 * editable comboboxes. This property can be set either on a single combobox
-	 * or globally on {@link UIManager}. The value in both cases should be an
-	 * instance of {@link AutoCompletionMatcher}. The default implementation is
-	 * in {@link DefaultAutoCompletionMatcher} and uses case-ignore string
-	 * matching.
-	 * </p>
-	 * 
-	 * @see #COMBO_BOX_NO_AUTOCOMPLETION
-	 * @see #COMBO_BOX_USE_MODEL_ONLY
-	 * @since 3.1
-	 */
-	public final static String COMBO_BOX_AUTOCOMPLETION_MATCHER = "lafwidgets.comboboxAutoCompletionMatcher";
-
+public interface LafWidget<T extends JComponent> {
 	/**
 	 * <p>
 	 * Client property name for specifying that the {@link LockBorderWidget}
@@ -378,7 +309,7 @@ public interface LafWidget {
 	 * @param jcomp
 	 *            Component.
 	 */
-	public void setComponent(JComponent jcomp);
+	public void setComponent(T jcomp);
 
 	/**
 	 * Returns indication whether <code>this</code> widget requires custom LAF
