@@ -36,18 +36,19 @@ import javax.swing.JComponent;
  * 
  * @author Kirill Grouchnikov
  */
-public abstract class LafWidgetAdapter implements LafWidget {
+public abstract class LafWidgetAdapter<T extends JComponent> implements
+		LafWidget<T> {
 	/**
 	 * Associated component.
 	 */
-	protected JComponent jcomp;
+	protected T jcomp;
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidget#setComponent(javax.swing.JComponent)
 	 */
-	public void setComponent(JComponent jcomp) {
+	public void setComponent(T jcomp) {
 		this.jcomp = jcomp;
 	}
 
