@@ -36,8 +36,6 @@ import java.util.*;
 
 import javax.swing.JComponent;
 
-import org.jvnet.lafwidget.animation.FadeIgnoreManager;
-
 /**
  * Repository of LAF widgets.
  * 
@@ -70,8 +68,7 @@ public class LafWidgetRepository {
 	/**
 	 * Manages the components that ignore animations.
 	 */
-	protected FadeIgnoreManager fadeIgnoreManager;
-
+	// protected FadeIgnoreManager fadeIgnoreManager;
 	/**
 	 * Singleton instance.
 	 */
@@ -109,9 +106,9 @@ public class LafWidgetRepository {
 		 * Creates a new info object.
 		 * 
 		 * @param className
-		 *            Class name.
+		 * 		Class name.
 		 * @param isExact
-		 *            Indicates whether the matching should be exact.
+		 * 		Indicates whether the matching should be exact.
 		 */
 		public LafWidgetClassInfo(String className, boolean isExact) {
 			this.className = className;
@@ -126,7 +123,7 @@ public class LafWidgetRepository {
 		this.widgets = new HashMap<Class<?>, Set<LafWidgetClassInfo>>();
 		this.lafSupport = new LafWidgetSupport();
 		this.isCustomLafSupportSet = false;
-		this.fadeIgnoreManager = new FadeIgnoreManager();
+		// this.fadeIgnoreManager = new FadeIgnoreManager();
 		this.widgetClassesToIgnore = new HashSet<String>();
 	}
 
@@ -139,7 +136,7 @@ public class LafWidgetRepository {
 		if (LafWidgetRepository.repository == null) {
 			LafWidgetRepository.repository = new LafWidgetRepository();
 			LafWidgetRepository.repository.populate();
-			LafWidgetRepository.repository.fadeIgnoreManager.populate();
+			// LafWidgetRepository.repository.fadeIgnoreManager.populate();
 		}
 		return LafWidgetRepository.repository;
 	}
@@ -152,12 +149,12 @@ public class LafWidgetRepository {
 	 * property file:
 	 * 
 	 * <pre>
-	 *             org.jvnet.lafwidget.text.PasswordStrengthCheckerWidget = javax.swing.JPasswordField
+	 * org.jvnet.lafwidget.text.PasswordStrengthCheckerWidget = javax.swing.JPasswordField
 	 *             org.jvnet.lafwidget.text.LockBorderWidget = javax.swing.text.JTextComponent;javax.swing.JComboBox
 	 * </pre>
 	 * 
 	 * @param url
-	 *            URL that points to a properties file.
+	 * 		URL that points to a properties file.
 	 */
 	protected void populateFrom(URL url) {
 		Properties props = new Properties();
@@ -228,9 +225,9 @@ public class LafWidgetRepository {
 	 * contain {@link Class} instances.
 	 * 
 	 * @param widgetClassName
-	 *            Full-qualified class name for the widget.
+	 * 		Full-qualified class name for the widget.
 	 * @param supportedClasses
-	 *            Classes supported by the widget.
+	 * 		Classes supported by the widget.
 	 */
 	public synchronized void registerWidget(String widgetClassName,
 			List<Class<?>> supportedClasses) {
@@ -242,15 +239,15 @@ public class LafWidgetRepository {
 	 * Registers a new widget for the specified UI class.
 	 * 
 	 * @param widgetClassName
-	 *            Full-qualified class name for the widget.
+	 * 		Full-qualified class name for the widget.
 	 * @param supportedClass
-	 *            Class supported by the widget.
+	 * 		Class supported by the widget.
 	 * @param isExact
-	 *            if <code>true</code>, the widget will be available only for
-	 *            the components of the specified class. If <code>false</code>,
-	 *            the widget be available for the components of the specified
-	 *            class and all its descendants (as defined in the
-	 *            {@link Class#isAssignableFrom(Class)}).
+	 * 		if <code>true</code>, the widget will be available only for the
+	 * 		components of the specified class. If <code>false</code>, the widget
+	 * 		be available for the components of the specified class and all its
+	 * 		descendants (as defined in the {@link Class#isAssignableFrom(Class)}
+	 * 		).
 	 */
 	public synchronized void registerWidget(String widgetClassName,
 			Class<?> supportedClass, boolean isExact) {
@@ -273,14 +270,14 @@ public class LafWidgetRepository {
 	/**
 	 * Returns a set of widgets that match the specified component. The
 	 * component hierarchy is scanned bottom-up and all matching widget classes
-	 * are used to instantiate new instance of widgets. In case the
-	 * {@link #isCustomLafSupportSet} is <code>false</code>, only widgets
-	 * that return <code>false</code> in
-	 * {@link LafWidget#requiresCustomLafSupport()} are returned.
+	 * are used to instantiate new instance of widgets. In case the {@link
+	 * #isCustomLafSupportSet} is <code>false</code>, only widgets that return
+	 * <code>false</code> in {@link LafWidget#requiresCustomLafSupport()} are
+	 * returned.
 	 * 
 	 * 
 	 * @param jcomp
-	 *            UI component.
+	 * 		UI component.
 	 * @return Set of widgets that match the specified component.
 	 */
 	public synchronized Set<LafWidget> getMatchingWidgets(JComponent jcomp) {
@@ -336,9 +333,9 @@ public class LafWidgetRepository {
 	 * Sets LAF support.
 	 * 
 	 * @param lafSupport
-	 *            LAF support.
+	 * 		LAF support.
 	 * @throws IllegalArgumentException
-	 *             If the LAF support is <code>null</code>.
+	 * 		If the LAF support is <code>null</code>.
 	 */
 	public void setLafSupport(LafWidgetSupport lafSupport) {
 		if (lafSupport == null)
@@ -392,7 +389,7 @@ public class LafWidgetRepository {
 	 * Retrieves the label bundle for the specified locale.
 	 * 
 	 * @param locale
-	 *            Locale.
+	 * 		Locale.
 	 * @return The label bundle for the specified locale.
 	 */
 	public static synchronized ResourceBundle getLabelBundle(Locale locale) {
@@ -423,7 +420,7 @@ public class LafWidgetRepository {
 	 * Sets the class loader for {@link #LABEL_BUNDLE}.
 	 * 
 	 * @param labelBundleClassLoader
-	 *            Class loader for {@link #LABEL_BUNDLE}.
+	 * 		Class loader for {@link #LABEL_BUNDLE}.
 	 * @since version 1.1
 	 */
 	public static void setLabelBundleClassLoader(
@@ -431,21 +428,21 @@ public class LafWidgetRepository {
 		LafWidgetRepository.labelBundleClassLoader = labelBundleClassLoader;
 	}
 
-	/**
-	 * Retrieves the manager for components that ignore animations.
-	 * 
-	 * @return The manager for components that ignore animations.
-	 */
-	public FadeIgnoreManager getFadeIgnoreManager() {
-		return fadeIgnoreManager;
-	}
+	// /**
+	// * Retrieves the manager for components that ignore animations.
+	// *
+	// * @return The manager for components that ignore animations.
+	// */
+	// public FadeIgnoreManager getFadeIgnoreManager() {
+	// return fadeIgnoreManager;
+	// }
 
 	/**
 	 * Marks widget with the specified class name to never be installed on any
 	 * components.
 	 * 
 	 * @param widgetClassName
-	 *            Fully qualified widget class name.
+	 * 		Fully qualified widget class name.
 	 */
 	public synchronized void addToIgnoreWidgets(String widgetClassName) {
 		this.widgetClassesToIgnore.add(widgetClassName);
