@@ -346,13 +346,6 @@ public class LafWidgetSupport {
 		if (Boolean.TRUE.equals(UIManager.get(LafWidget.NO_LOCK_ICON)))
 			return false;
 
-		if (comp instanceof JComboBox) {
-			JComboBox combo = (JComboBox) comp;
-			if (combo.isEditable()
-					&& LafWidgetUtilities.hasUseModelOnlyProperty(combo))
-				return true;
-			return false;
-		}
 		if (comp instanceof JTextComponent) {
 			JTextComponent textComp = (JTextComponent) comp;
 			return !textComp.isEditable();
