@@ -64,9 +64,9 @@ public class LafWidgetUtilities {
 	 * Retrieves transparent image of specified dimension.
 	 * 
 	 * @param width
-	 *            Image width.
+	 * 		Image width.
 	 * @param height
-	 *            Image height.
+	 * 		Image height.
 	 * @return Transparent image of specified dimension.
 	 */
 	public static BufferedImage getBlankImage(int width, int height) {
@@ -83,53 +83,11 @@ public class LafWidgetUtilities {
 		return image;
 	}
 
-	/**
-	 * Checks whether the specified combobox has "use model only" property.
-	 * 
-	 * @param combobox
-	 *            Combobox.
-	 * @return <code>true</code> if the specified combobox has "use model
-	 *         only" property, <code>false</code> otherwise.
-	 */
-	public static boolean hasUseModelOnlyProperty(JComboBox combobox) {
-		Object useModelOnlyProperty = combobox
-				.getClientProperty(LafWidget.COMBO_BOX_USE_MODEL_ONLY);
-		if (Boolean.TRUE.equals(useModelOnlyProperty))
-			return true;
-		if (Boolean.FALSE.equals(useModelOnlyProperty))
-			return false;
-		return (Boolean.TRUE.equals(UIManager
-				.get(LafWidget.COMBO_BOX_USE_MODEL_ONLY)));
-	}
-
-	/**
-	 * Checks whether the specified combobox has auto-completion.
-	 * 
-	 * @param combobox
-	 *            Combobox.
-	 * @return <code>true</code> if the specified combobox has
-	 *         auto-completion, <code>false</code> otherwise.
-	 */
-	public static boolean hasAutoCompletion(JComboBox combobox) {
-		if (Boolean.TRUE.equals(combobox
-				.getClientProperty("JComboBox.isTableCellEditor")))
-			return false;
-		Object noAutoCompletion = combobox
-				.getClientProperty(LafWidget.COMBO_BOX_NO_AUTOCOMPLETION);
-		if (Boolean.FALSE.equals(noAutoCompletion))
-			return combobox.isEditable();
-		if (Boolean.TRUE.equals(noAutoCompletion))
-			return false;
-		return combobox.isEditable()
-				&& (!Boolean.TRUE.equals(UIManager
-						.get(LafWidget.COMBO_BOX_NO_AUTOCOMPLETION)));
-	}
-
 	/**
 	 * Creates a compatible image (for efficient processing and drawing).
 	 * 
 	 * @param image
-	 *            The original image.
+	 * 		The original image.
 	 * @return Compatible version of the original image.
 	 * @author Romain Guy
 	 */
@@ -150,9 +108,9 @@ public class LafWidgetUtilities {
 	 * Creates a thumbnail of the specified width.
 	 * 
 	 * @param image
-	 *            The original image.
+	 * 		The original image.
 	 * @param requestedThumbWidth
-	 *            The width of the resulting thumbnail.
+	 * 		The width of the resulting thumbnail.
 	 * @return Thumbnail of the specified width.
 	 * @author Romain Guy
 	 */
@@ -186,9 +144,9 @@ public class LafWidgetUtilities {
 	 * Returns search icon.
 	 * 
 	 * @param dimension
-	 *            Icon dimension.
+	 * 		Icon dimension.
 	 * @param leftToRight
-	 *            Indicates the orientation of the resulting icon.
+	 * 		Indicates the orientation of the resulting icon.
 	 * @return Search icon.
 	 */
 	public static Icon getSearchIcon(int dimension, boolean leftToRight) {
@@ -240,7 +198,7 @@ public class LafWidgetUtilities {
 	 * arranged in 2*2 grid.
 	 * 
 	 * @param value
-	 *            Integer value to represent.
+	 * 		Integer value to represent.
 	 * @return Icon representation of the specified integer value.
 	 */
 	public static Icon getHexaMarker(int value) {
@@ -276,12 +234,11 @@ public class LafWidgetUtilities {
 	 * Makes the specified component and all its descendants previewable.
 	 * 
 	 * @param comp
-	 *            Component.
+	 * 		Component.
 	 * @param dbSnapshot
-	 *            The "snapshot" map that will contain the original
-	 *            double-buffer status of the specified component and all its
-	 *            descendants. Key is {@link JComponent}, value is
-	 *            {@link Boolean}.
+	 * 		The "snapshot" map that will contain the original double-buffer
+	 * 		status of the specified component and all its descendants. Key is
+	 * 		{@link JComponent}, value is {@link Boolean}.
 	 */
 	public static void makePreviewable(Component comp,
 			Map<Component, Boolean> dbSnapshot) {
@@ -309,11 +266,11 @@ public class LafWidgetUtilities {
 	 * and all its descendants.
 	 * 
 	 * @param comp
-	 *            Component.
+	 * 		Component.
 	 * @param dbSnapshot
-	 *            The "snapshot" map that contains the original double-buffer
-	 *            status of the specified component and all its descendants. Key
-	 *            is {@link JComponent}, value is {@link Boolean}.
+	 * 		The "snapshot" map that contains the original double-buffer status
+	 * 		of the specified component and all its descendants. Key is {@link
+	 * 		JComponent}, value is {@link Boolean}.
 	 */
 	public static void restorePreviewable(Component comp,
 			Map<Component, Boolean> dbSnapshot) {
@@ -352,7 +309,7 @@ public class LafWidgetUtilities {
 	 * Returns the animation kind of the specified component.
 	 * 
 	 * @param component
-	 *            Component.
+	 * 		Component.
 	 * @return The animation kind of the specified component.
 	 */
 	public static AnimationKind getAnimationKind(Component component) {
@@ -416,13 +373,13 @@ public class LafWidgetUtilities {
 	}
 
 	/**
-	 * Checks whether the specified text component has "select all on focus
-	 * gain" property.
+	 * Checks whether the specified text component has
+	 * "select all on focus gain" property.
 	 * 
 	 * @param textComp
-	 *            Text component.
-	 * @return <code>true</code> if the specified text component has "select
-	 *         all on focus gain" property, <code>false</code> otherwise.
+	 * 		Text component.
+	 * @return <code>true</code> if the specified text component has "select all
+	 * 	on focus gain" property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextFocusSelectAllProperty(JTextComponent textComp) {
 		Component comp = textComp;
@@ -446,9 +403,9 @@ public class LafWidgetUtilities {
 	 * property.
 	 * 
 	 * @param textComp
-	 *            Text component.
+	 * 		Text component.
 	 * @return <code>true</code> if the specified text component has "flip
-	 *         select on escape" property, <code>false</code> otherwise.
+	 * 	select on escape" property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextFlipSelectOnEscapeProperty(
 			JTextComponent textComp) {
@@ -467,9 +424,9 @@ public class LafWidgetUtilities {
 	 * property.
 	 * 
 	 * @param textComp
-	 *            Text component.
+	 * 		Text component.
 	 * @return <code>true</code> if the specified text component has edit
-	 *         context menu property, <code>false</code> otherwise.
+	 * 	context menu property, <code>false</code> otherwise.
 	 */
 	public static boolean hasTextEditContextMenu(JTextComponent textComp) {
 		Object textEditContextMenuProperty = textComp
@@ -486,9 +443,9 @@ public class LafWidgetUtilities {
 	 * Checks whether the specified scroll pane supports auto scroll.
 	 * 
 	 * @param scrollPane
-	 *            Scroll pane component.
+	 * 		Scroll pane component.
 	 * @return <code>true</code> if the specified scroll pane supports auto
-	 *         scroll, <code>false</code> otherwise.
+	 * 	scroll, <code>false</code> otherwise.
 	 */
 	public static boolean hasAutoScroll(JScrollPane scrollPane) {
 		Object compProperty = scrollPane
@@ -505,9 +462,9 @@ public class LafWidgetUtilities {
 	 * support.
 	 * 
 	 * @param tree
-	 *            Tree component.
+	 * 		Tree component.
 	 * @return <code>true</code> if the specified text component has automatic
-	 *         drag and drop support, <code>false</code> otherwise.
+	 * 	drag and drop support, <code>false</code> otherwise.
 	 */
 	public static boolean hasAutomaticDnDSupport(JTree tree) {
 		Object dndProperty = tree
@@ -525,12 +482,11 @@ public class LafWidgetUtilities {
 	 * the specified component.
 	 * 
 	 * @param jcomp
-	 *            Component.
-	 * @return <code>true</code> if the custom labels should be looked up
-	 *         based on the component locale as returned by
-	 *         {@link JComponent#getLocale()}, <code>false</code> if the
-	 *         custom labels should be looked up based on the global locale as
-	 *         returned by {@link Locale#getDefault()}.
+	 * 		Component.
+	 * @return <code>true</code> if the custom labels should be looked up based
+	 * 	on the component locale as returned by {@link JComponent#getLocale()},
+	 * 	<code>false</code> if the custom labels should be looked up based on the
+	 * 	global locale as returned by {@link Locale#getDefault()}.
 	 */
 	public static boolean toIgnoreGlobalLocale(JComponent jcomp) {
 		if (jcomp == null)
@@ -543,7 +499,7 @@ public class LafWidgetUtilities {
 	 * Returns the resource bundle for the specified component.
 	 * 
 	 * @param jcomp
-	 *            Component.
+	 * 		Component.
 	 * @return Resource bundle for the specified component.
 	 */
 	public static ResourceBundle getResourceBundle(JComponent jcomp) {
@@ -560,11 +516,11 @@ public class LafWidgetUtilities {
 	 * large tables and lists.
 	 * 
 	 * @param comp
-	 *            Component.
+	 * 		Component.
 	 * @param fadeKind
-	 *            Fade kind.
-	 * @return <code>true</code> if the specified fade kind has no animations
-	 *         on the specified component, <code>false</code> otherwise.
+	 * 		Fade kind.
+	 * @return <code>true</code> if the specified fade kind has no animations on
+	 * 	the specified component, <code>false</code> otherwise.
 	 */
 	public static boolean hasNoFades(Component comp, FadeKind fadeKind) {
 		return (LafWidgetUtilities.getAnimationKind(comp) == AnimationKind.NONE)
@@ -577,7 +533,7 @@ public class LafWidgetUtilities {
 	 * internal use only</b>.
 	 * 
 	 * @param b
-	 *            Button.
+	 * 		Button.
 	 * @return Icon for the specified button.
 	 */
 	public static Icon getIcon(AbstractButton b) {
@@ -612,4 +568,11 @@ public class LafWidgetUtilities {
 		}
 		return icon;
 	}
+
+	public static boolean toIgnoreAnimations(Component comp) {
+		if (comp instanceof JMenuItem)
+			return false;
+		return (SwingUtilities.getAncestorOfClass(CellRendererPane.class, comp) != null);
+	}
+
 }
