@@ -34,8 +34,6 @@ import java.awt.Container;
 
 import javax.swing.*;
 
-import org.jvnet.lafwidget.combo.AutoCompletionMatcher;
-import org.jvnet.lafwidget.combo.DefaultAutoCompletionMatcher;
 import org.jvnet.lafwidget.preview.PreviewPainter;
 import org.jvnet.lafwidget.tabbed.TabPreviewPainter;
 import org.jvnet.lafwidget.text.PasswordStrengthChecker;
@@ -128,23 +126,4 @@ public class LafWidgetUtilities2 {
 			return (PasswordStrengthChecker) obj;
 		return null;
 	}
-
-	/**
-	 * Returns the auto-completion matcher for the specified combobox.
-	 * 
-	 * @param combo
-	 *            Combobox.
-	 * @return Auto-completion matcher for the specified combobox.
-	 */
-	public static AutoCompletionMatcher getAutoCompletionMatcher(JComboBox combo) {
-		Object specific = combo
-				.getClientProperty(LafWidget.COMBO_BOX_AUTOCOMPLETION_MATCHER);
-		if (specific instanceof AutoCompletionMatcher)
-			return (AutoCompletionMatcher) specific;
-		Object global = UIManager
-				.get(LafWidget.COMBO_BOX_AUTOCOMPLETION_MATCHER);
-		if (global instanceof AutoCompletionMatcher)
-			return (AutoCompletionMatcher) global;
-		return new DefaultAutoCompletionMatcher();
-	}
 }
