@@ -32,6 +32,8 @@ package org.jvnet.lafwidget.animation;
 import java.awt.Component;
 import java.util.*;
 
+import org.jvnet.lafwidget.LafWidget;
+import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
 
 /**
  * Fade configuration manager.
@@ -248,13 +250,13 @@ public class FadeConfigurationManager {
 	 *         specified component, <code>false</code> otherwise.
 	 */
 	public synchronized boolean fadeAllowed(FadeKind fadeKind, Component comp) {
-		Set<Component> instanceAllowed = this.instanceAllowed.get(fadeKind);
 		Set<Component> instanceDisallowed = this.instanceDisallowed
 				.get(fadeKind);
 		if (instanceDisallowed != null) {
 			if (instanceDisallowed.contains(comp))
 				return false;
 		}
+		Set<Component> instanceAllowed = this.instanceAllowed.get(fadeKind);
 		if (instanceAllowed != null) {
 			if (instanceAllowed.contains(comp))
 				return true;
@@ -281,4 +283,37 @@ public class FadeConfigurationManager {
 			return true;
 		return false;
 	}
+
+	/**
+	 * Registers the specified application callback for tracking core fade
+	 * events. This allows the applications to track different stages of
+	 * animation sequences. For example, the action listener on button press is
+	 * called immediately on mouse release. However, the sequence going from
+	 * pressed state to rollover state takes some time (depending on the current
+	 * animation speed setting controlled by {@link AnimationKind} and
+	 * {@link LafWidget#ANIMATION_KIND}). An application that wishes to take a
+	 * frame snapshot with the final (rollover) state of the button can register
+	 * a global fade tracker callback that will take the snapshot at the end of
+	 * the fade sequence.
+	 * 
+	 * @param callback
+	 *            Application callback for tracking core fade events.
+	 * @see #removeGlobalFadeTrackerCallback(GlobalFadeTrackerCallback)
+	 */
+	public static void addGlobalFadeTrackerCallback(
+			GlobalFadeTrackerCallback callback) {
+		FadeTracker.getInstance().addGlobalCallback(callback);
+	}
+
+	/**
+	 * Removes the specified application callback for tracking core fade events.
+	 * 
+	 * @param callback
+	 *            Application callback to remove.
+	 * @see #addGlobalFadeTrackerCallback(GlobalFadeTrackerCallback)
+	 */
+	public static void removeGlobalFadeTrackerCallback(
+			GlobalFadeTrackerCallback callback) {
+		FadeTracker.getInstance().removeGlobalCallback(callback);
+	}
 }
