@@ -40,6 +40,8 @@ public class FadeKind {
 	 */
 	protected String id;
 
+	protected boolean isCore;
+
 	/**
 	 * Creates a new fade kind which is allowed by default.
 	 * 
@@ -60,26 +62,45 @@ public class FadeKind {
 	 *            default.
 	 */
 	public FadeKind(String id, boolean isDefaultAllowed) {
+		this(id, isDefaultAllowed, false);
+	}
+
+	/**
+	 * Creates a new fade kind.
+	 * 
+	 * @param id
+	 *            Fade kind ID.
+	 * @param isDefaultAllowed
+	 *            Indicates whether the newly create fade kind is allowed by
+	 *            default.
+	 * @param isCore
+	 *            If <code>true</code>, this fade kind will be reported to the
+	 *            listeners registered with
+	 *            {@link FadeConfigurationManager#addGlobalFadeTrackerCallback(GlobalFadeTrackerCallback)}
+	 *            .
+	 */
+	private FadeKind(String id, boolean isDefaultAllowed, boolean isCore) {
 		this.id = id;
 		if (isDefaultAllowed) {
 			FadeConfigurationManager.getInstance().allowFades(this);
 		}
+		this.isCore = isCore;
 	}
 
 	/**
 	 * Arming a component.
 	 */
-	public static final FadeKind ARM = new FadeKind("lafwidgets.core.arm");
+	public static final FadeKind ARM = new FadeKind("lafwidgets.core.arm", true, true);
 
 	/**
 	 * Pressing a component.
 	 */
-	public static final FadeKind PRESS = new FadeKind("lafwidgets.core.press");
+	public static final FadeKind PRESS = new FadeKind("lafwidgets.core.press", true, true);
 
 	/**
 	 * Focusing a component.
 	 */
-	public static final FadeKind FOCUS = new FadeKind("lafwidgets.core.focus");
+	public static final FadeKind FOCUS = new FadeKind("lafwidgets.core.focus", true, true);
 
 	/**
 	 * <p>
@@ -95,19 +116,19 @@ public class FadeKind {
 	/**
 	 * Enabling a component.
 	 */
-	public static final FadeKind ENABLE = new FadeKind("lafwidgets.core.enable");
+	public static final FadeKind ENABLE = new FadeKind("lafwidgets.core.enable", true, true);
 
 	/**
 	 * Rollover a component.
 	 */
 	public static final FadeKind ROLLOVER = new FadeKind(
-			"lafwidgets.core.rollover");
+			"lafwidgets.core.rollover", true, true);
 
 	/**
 	 * Selecting a component.
 	 */
 	public static final FadeKind SELECTION = new FadeKind(
-			"lafwidgets.core.selection");
+			"lafwidgets.core.selection", true, true);
 
 	/**
 	 * Fade kind that specifies the "ghosting image" effects on button icons
