@@ -38,8 +38,8 @@ import javax.swing.ButtonModel;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import org.jvnet.lafwidget.LafWidgetRepository;
 import org.jvnet.lafwidget.LafWidgetUtilities;
+import org.jvnet.lafwidget.animation.FadeTracker.ComponentId;
 
 /**
  * Implements listener on model changes of some component. Once model changes
@@ -63,6 +63,8 @@ public class FadeStateListener {
 	 */
 	protected ButtonModel buttonModel;
 
+	protected Comparable<?> extraKey;
+
 	/**
 	 * Key - {@link FadeKind}, value - {@link Boolean}
 	 */
@@ -93,15 +95,15 @@ public class FadeStateListener {
 	 * transitions.
 	 * 
 	 * @param comp
-	 *            Component.
+	 * 		Component.
 	 * @param buttonModel
-	 *            Model for the component.
+	 * 		Model for the component.
 	 * @param callback
-	 *            Optional application callback.
+	 * 		Optional application callback.
 	 */
 	public FadeStateListener(Component comp, ButtonModel buttonModel,
 			FadeTrackerCallback callback) {
-		this(comp, buttonModel, callback, new HashSet<FadeKind>());
+		this(comp, null, buttonModel, callback, null);
 	}
 
 	/**
@@ -109,20 +111,21 @@ public class FadeStateListener {
 	 * transitions.
 	 * 
 	 * @param comp
-	 *            Component.
+	 * 		Component.
 	 * @param buttonModel
-	 *            Model for the component.
+	 * 		Model for the component.
 	 * @param callback
-	 *            Optional application callback.
+	 * 		Optional application callback.
 	 * @param toIgnore
-	 *            Set of fade kinds to ignore.
+	 * 		Set of fade kinds to ignore.
 	 */
-	public FadeStateListener(Component comp, ButtonModel buttonModel,
-			FadeTrackerCallback callback, Set<FadeKind> toIgnore) {
+	public FadeStateListener(Component comp, Comparable<?> extraKey,
+			ButtonModel buttonModel, FadeTrackerCallback callback,
+			Set<FadeKind> toIgnore) {
 		this.comp = comp;
+		this.extraKey = extraKey;
 		this.buttonModel = buttonModel;
 		this.callback = callback;
-		this.toIgnore = toIgnore;
 
 		this.prevStateMap = new HashMap<FadeKind, Boolean>();
 		if (buttonModel != null) {
@@ -140,24 +143,22 @@ public class FadeStateListener {
 	 * Tracks a single change to the model.
 	 * 
 	 * @param fadeKind
-	 *            Fade animation kind.
+	 * 		Fade animation kind.
 	 * @param newValue
-	 *            New value of the relevant attribute of the model.
+	 * 		New value of the relevant attribute of the model.
 	 * @param toRepaintParent
-	 *            If <code>true</code>, the component parent will be
-	 *            repainted at every animation cycle. If <code>false</code>,
-	 *            the component itself will be repainted at every animation
-	 *            cycle.
+	 * 		If <code>true</code>, the component parent will be repainted at
+	 * 		every animation cycle. If <code>false</code>, the component itself
+	 * 		will be repainted at every animation cycle.
 	 */
 	protected void trackModelChange(FadeKind fadeKind, boolean newValue,
 			boolean toRepaintParent) {
 		// special handling of cell renderers and editors - no
 		// animation there
-		if (LafWidgetRepository.getRepository().getFadeIgnoreManager()
-				.toIgnoreAnimations(this.comp))
+		if (LafWidgetUtilities.toIgnoreAnimations(this.comp))
 			return;
 
-		if (this.toIgnore.contains(fadeKind)) {
+		if ((this.toIgnore != null) && this.toIgnore.contains(fadeKind)) {
 			if (this.callback != null) {
 				this.callback.fadeEnded(fadeKind);
 			} else {
@@ -192,8 +193,16 @@ public class FadeStateListener {
 					}
 				}
 			}
-			FadeTracker.getInstance().trackFade(this.comp, fadeKind, newValue,
-					toRepaintParent, this.callback);
+			if (newValue) {
+				FadeTracker.getInstance().trackFadeIn(fadeKind, this.comp,
+						this.extraKey, toRepaintParent, this.callback);
+			} else {
+				FadeTracker.getInstance().trackFadeOut(fadeKind, this.comp,
+						this.extraKey, toRepaintParent, this.callback);
+			}
+			// FadeTracker.getInstance().trackFade(this.comp, fadeKind, newValue
+			// ,
+			// toRepaintParent, this.callback);
 		} finally {
 			this.prevStateMap.put(fadeKind, newValue);
 		}
@@ -210,10 +219,9 @@ public class FadeStateListener {
 	 * Registers listeners on all model changes.
 	 * 
 	 * @param toRepaintParent
-	 *            If <code>true</code>, the component parent will be
-	 *            repainted at every animation cycle. If <code>false</code>,
-	 *            the component itself will be repainted at every animation
-	 *            cycle.
+	 * 		If <code>true</code>, the component parent will be repainted at
+	 * 		every animation cycle. If <code>false</code>, the component itself
+	 * 		will be repainted at every animation cycle.
 	 */
 	public void registerListeners(final boolean toRepaintParent) {
 		this.modelListener = new ChangeListener() {
@@ -271,10 +279,12 @@ public class FadeStateListener {
 	protected void initiateFocusFadeLoop() {
 		FadeTrackerCallback loopCallback = (callback != null) ? callback
 				: new FadeTrackerAdapter() {
+					@Override
 					public void fadeEnded(FadeKind fadeKind) {
 						comp.repaint();
 					}
 
+					@Override
 					public void fadePerformed(FadeKind fadeKind,
 							float fadeCycle10) {
 						comp.repaint();
@@ -285,7 +295,8 @@ public class FadeStateListener {
 			focusLoopFadeInstanceId = FadeTracker.getInstance()
 					.trackFadeLooping(FadeKind.FOCUS_LOOP_ANIMATION,
 							LafWidgetUtilities.getAnimationKind(this.comp),
-							this.comp, null, false, loopCallback, -1, false);
+							this.comp, this.extraKey, false, loopCallback, -1,
+							false);
 		}
 	}
 
