@@ -48,11 +48,11 @@ public class FadeTracker {
 	/**
 	 * Max value for fade cycle.
 	 */
-	public static final int END_VALUE = 10;
+	public static final int END_VALUE = 1;
 
 	/**
-	 * Debug mode indicator. Set to <code>true</code> to have trace messages
-	 * on console.
+	 * Debug mode indicator. Set to <code>true</code> to have trace messages on
+	 * console.
 	 */
 	public static boolean DEBUG_MODE = false;
 
@@ -81,6 +81,11 @@ public class FadeTracker {
 	 */
 	private long currLoopId;
 
+	/**
+	 * List of global fade tracker callbacks.
+	 */
+	private List<GlobalFadeTrackerCallback> globalCallbackList;
+
 	/**
 	 * Information on a single component under fade.
 	 * 
@@ -98,21 +103,21 @@ public class FadeTracker {
 		 * tab-specific animations.
 		 */
 		@SuppressWarnings("unchecked")
-		public Comparable id;
+		public Comparable subID;
 
 		/**
 		 * Creates a new component ID.
 		 * 
 		 * @param component
 		 *            UI component itself.
-		 * @param id
+		 * @param subID
 		 *            ID to distinguish between different sub-components of the
 		 *            UI component.
 		 */
 		@SuppressWarnings("unchecked")
-		public ComponentId(Component component, Comparable id) {
+		public ComponentId(Component component, Comparable subID) {
 			this.component = component;
-			this.id = id;
+			this.subID = subID;
 		}
 
 		/*
@@ -123,8 +128,8 @@ public class FadeTracker {
 		@Override
 		public int hashCode() {
 			int result = this.component.hashCode();
-			if (this.id != null)
-				result &= (this.id.hashCode());
+			if (this.subID != null)
+				result &= (this.subID.hashCode());
 			return result;
 		}
 
@@ -140,10 +145,11 @@ public class FadeTracker {
 				ComponentId cid = (ComponentId) obj;
 				try {
 					boolean result = (this.component == cid.component);
-					if (this.id == null) {
-						result = result && (cid.id == null);
+					if (this.subID == null) {
+						result = result && (cid.subID == null);
 					} else {
-						result = result && (this.id.compareTo(cid.id) == 0);
+						result = result
+								&& (this.subID.compareTo(cid.subID) == 0);
 					}
 					return result;
 				} catch (Exception exc) {
@@ -232,16 +238,7 @@ public class FadeTracker {
 		this.fadeInstances = new HashMap<Long, FadeKind>();
 		this.currLoopId = 0;
 
-		// FadeConfigurationManager configManager = FadeConfigurationManager
-		// .getInstance();
-		// configManager.allowFades(FadeKind.ARM);
-		// configManager.allowFades(FadeKind.ENABLE);
-		// configManager.allowFades(FadeKind.FOCUS);
-		// configManager.allowFades(FadeKind.PRESS);
-		// configManager.allowFades(FadeKind.ROLLOVER);
-		// configManager.allowFades(FadeKind.SELECTION);
-		// this.sdf = new SimpleDateFormat("dd/MM/yyyy HH:mm:ss.SSS");
-		// this.int2comp = new ArrayList<Set<JComponent>>();
+		this.globalCallbackList = new ArrayList<GlobalFadeTrackerCallback>();
 	}
 
 	/**
@@ -262,9 +259,12 @@ public class FadeTracker {
 	 * {@link FadeState#toRepaintParent}) and optional call to the callback.
 	 */
 	private synchronized void updateComponents() {
+		if (this.trackedComponents.size() == 0)
+			return;
+
 		// if (this.comp2int.size() > 0)
 		// System.out.println("Periodic update");
-		Set<Container> parents = new HashSet<Container>();
+		Set<Container> parents = null;
 		for (Iterator<Map.Entry<FadeKind, Map<ComponentId, FadeState>>> itComp = this.trackedComponents
 				.entrySet().iterator(); itComp.hasNext();) {
 			Map.Entry<FadeKind, Map<ComponentId, FadeState>> entryComp = itComp
@@ -316,6 +316,9 @@ public class FadeTracker {
 									if (state.getCallback() != null)
 										callbackCallFadeEnded(state
 												.getCallback(), state.fadeKind);
+									this.globalCallbackCallFadeEnded(
+											compId.component, compId.subID,
+											state.fadeKind);
 									itKind.remove();
 								} else {
 									state.setFadePosition(0.0f);
@@ -370,7 +373,7 @@ public class FadeTracker {
 								System.out.println("Ending " + state.id
 										+ " on " + state.fadeKind.toString());
 							}
-							callbackCallFadeEnded(state.getCallback(),
+							this.callbackCallFadeEnded(state.getCallback(),
 									state.fadeKind);
 						} else {
 							if (DEBUG_MODE) {
@@ -378,15 +381,30 @@ public class FadeTracker {
 										+ " on " + state.fadeKind.toString()
 										+ " at " + state.getFadePosition());
 							}
-							callbackCallFadePerformed(compId.component, state
-									.getCallback(), state.fadeKind, state
-									.getFadePosition());
+							this.callbackCallFadePerformed(state.getCallback(),
+									state.fadeKind, state.getFadePosition());
 						}
+						// continue;
+					}
+					if (hasEnded) {
+						this.globalCallbackCallFadeEnded(compId.component,
+								compId.subID, state.fadeKind);
+					} else {
+						this.globalCallbackCallFadePerformed(compId.component,
+								compId.subID, state.fadeKind, state
+										.getFadePosition());
+					}
+					// if we have an internal callback, go to the next component
+					if (state.getCallback() != null) {
 						continue;
 					}
-					if (state.isToRepaintParent())
+
+					if (state.isToRepaintParent()) {
+						// Lazy creation for performance
+						if (parents == null)
+							parents = new HashSet<Container>();
 						parents.add(compId.component.getParent());
-					else {
+					} else {
 						compId.component.repaint();
 					}
 				}
@@ -405,19 +423,21 @@ public class FadeTracker {
 			// + (time1 - time0));
 			// }
 		}
-		for (Iterator<Container> itParent = parents.iterator(); itParent
-				.hasNext();) {
-			Container parent = itParent.next();
-			parent.repaint();
+		if ((parents != null) && (parents.size() > 0)) {
+			for (Iterator<Container> itParent = parents.iterator(); itParent
+					.hasNext();) {
+				Container parent = itParent.next();
+				parent.repaint();
+			}
 		}
 	}
 
 	private void callbackCallFadeEnded(final FadeTrackerCallback fadeCallback,
 			final FadeKind fadeKind) {
 		boolean shouldRunOnEDT = false;
-		Class clazz = fadeCallback.getClass();
+		Class<?> clazz = fadeCallback.getClass();
 		while ((clazz != null) && !shouldRunOnEDT) {
-			shouldRunOnEDT = clazz.isAnnotationPresent(RunOnEDT.class);
+			shouldRunOnEDT = clazz.isAnnotationPresent(RunOnUIThread.class);
 			clazz = clazz.getSuperclass();
 		}
 		if (shouldRunOnEDT) {
@@ -431,13 +451,34 @@ public class FadeTracker {
 		}
 	}
 
-	private void callbackCallFadePerformed(final Component comp,
+	private void callbackCallFadeReversed(
+			final FadeTrackerCallback fadeCallback, final FadeKind fadeKind,
+			final boolean isFadingIn, final float fadeCycle10) {
+		boolean shouldRunOnEDT = false;
+		Class<?> clazz = fadeCallback.getClass();
+		while ((clazz != null) && !shouldRunOnEDT) {
+			shouldRunOnEDT = clazz.isAnnotationPresent(RunOnUIThread.class);
+			clazz = clazz.getSuperclass();
+		}
+		if (shouldRunOnEDT) {
+			SwingUtilities.invokeLater(new Runnable() {
+				public void run() {
+					fadeCallback
+							.fadeReversed(fadeKind, isFadingIn, fadeCycle10);
+				}
+			});
+		} else {
+			fadeCallback.fadeReversed(fadeKind, isFadingIn, fadeCycle10);
+		}
+	}
+
+	private void callbackCallFadePerformed(
 			final FadeTrackerCallback fadeCallback, final FadeKind fadeKind,
 			final float fadePosition) {
 		boolean shouldRunOnEDT = false;
-		Class clazz = fadeCallback.getClass();
+		Class<?> clazz = fadeCallback.getClass();
 		while ((clazz != null) && !shouldRunOnEDT) {
-			shouldRunOnEDT = clazz.isAnnotationPresent(RunOnEDT.class);
+			shouldRunOnEDT = clazz.isAnnotationPresent(RunOnUIThread.class);
 			clazz = clazz.getSuperclass();
 		}
 		if (shouldRunOnEDT) {
@@ -451,6 +492,59 @@ public class FadeTracker {
 		}
 	}
 
+	private void globalCallbackCallFadeEnded(final Component comp,
+			final Comparable subID, final FadeKind fadeKind) {
+		if (this.globalCallbackList.size() == 0)
+			return;
+		if (!fadeKind.isCore)
+			return;
+
+		for (GlobalFadeTrackerCallback globalCallback : this.globalCallbackList) {
+			globalCallback.fadeEnded(comp, subID, fadeKind);
+		}
+	}
+
+	private void globalCallbackCallFadeStarted(final Component comp,
+			final Comparable subID, final FadeKind fadeKind,
+			float initialFadeCycle10) {
+		if (this.globalCallbackList.size() == 0)
+			return;
+		if (!fadeKind.isCore)
+			return;
+
+		for (GlobalFadeTrackerCallback globalCallback : this.globalCallbackList) {
+			globalCallback.fadeStarted(comp, subID, fadeKind,
+					initialFadeCycle10);
+		}
+	}
+
+	private void globalCallbackCallFadeReversed(final Component comp,
+			final Comparable subID, final FadeKind fadeKind,
+			final boolean isFadingIn, final float fadeCycle10) {
+		if (this.globalCallbackList.size() == 0)
+			return;
+		if (!fadeKind.isCore)
+			return;
+
+		for (GlobalFadeTrackerCallback globalCallback : this.globalCallbackList) {
+			globalCallback.fadeReversed(comp, subID, fadeKind, isFadingIn,
+					fadeCycle10);
+		}
+	}
+
+	private void globalCallbackCallFadePerformed(final Component comp,
+			final Comparable subID, final FadeKind fadeKind,
+			final float fadePosition) {
+		if (this.globalCallbackList.size() == 0)
+			return;
+		if (!fadeKind.isCore)
+			return;
+
+		for (GlobalFadeTrackerCallback globalCallback : this.globalCallbackList) {
+			globalCallback.fadePerformed(comp, subID, fadeKind, fadePosition);
+		}
+	}
+
 	/**
 	 * Returns the state of the component under the specified fade kind.
 	 * 
@@ -518,9 +612,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeIn(FadeKind fadeKind, Component comp,
 			boolean toRepaintParent, FadeTrackerCallback callback) {
@@ -543,9 +636,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeIn(FadeKind fadeKind, Component comp,
 			int componentId, boolean toRepaintParent,
@@ -570,9 +662,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeIn(FadeKind fadeKind, Component comp,
 			Comparable<?> componentId, boolean toRepaintParent,
@@ -599,9 +690,8 @@ public class FadeTracker {
 	 * @param aKind
 	 *            Animation kind. Should not be <code>null</code>.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeIn(FadeKind fadeKind, Component comp,
 			Comparable<?> componentId, boolean toRepaintParent,
@@ -614,20 +704,22 @@ public class FadeTracker {
 
 		if ((comp == null) || (!comp.isDisplayable())) {
 			if (callback != null) {
-				callbackCallFadeEnded(callback, fadeKind);
+				this.callbackCallFadeEnded(callback, fadeKind);
 			}
+			this.globalCallbackCallFadeEnded(comp, componentId, fadeKind);
 			return -1;
 		}
 
 		if (LafWidgetUtilities.hasNoFades(comp, fadeKind)) {
 			if (callback != null) {
-				callbackCallFadeEnded(callback, fadeKind);
+				this.callbackCallFadeEnded(callback, fadeKind);
 			} else {
 				if (toRepaintParent && comp.getParent() != null)
 					comp.getParent().repaint();
 				else
 					comp.repaint();
 			}
+			this.globalCallbackCallFadeEnded(comp, componentId, fadeKind);
 			return -1;
 		}
 
@@ -644,12 +736,18 @@ public class FadeTracker {
 			}
 			fadeState.setCallback(callback);
 			this.addState(comp, componentId, fadeKind, fadeState);
+			this.globalCallbackCallFadeStarted(comp, componentId, fadeKind,
+					fadeState.getFadePosition());
 		} else {
 			if (!fadeState.isFadingIn()) {
 				if (fadeState.getCallback() != null) {
-					fadeState.getCallback().fadeReversed(fadeKind, true,
-							fadeState.getFadePosition());
+					this.callbackCallFadeReversed(fadeState.getCallback(),
+							fadeKind, true, fadeState.getFadePosition());
+					// fadeState.getCallback().fadeReversed(fadeKind, true,
+					// fadeState.getFadePosition());
 				}
+				this.globalCallbackCallFadeReversed(comp, componentId,
+						fadeKind, true, fadeState.getFadePosition());
 			}
 			fadeState.setFadingIn(true);
 			fadeState.setCallback(callback);
@@ -673,9 +771,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeOut(FadeKind fadeKind, Component comp,
 			boolean toRepaintParent, FadeTrackerCallback callback) {
@@ -698,9 +795,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeOut(FadeKind fadeKind, Component comp,
 			int componentId, boolean toRepaintParent,
@@ -725,9 +821,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeOut(FadeKind fadeKind, Component comp,
 			Comparable<?> componentId, boolean toRepaintParent,
@@ -754,9 +849,8 @@ public class FadeTracker {
 	 * @param aKind
 	 *            Animation kind. Should not be <code>null</code>.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeOut(FadeKind fadeKind, Component comp,
 			Comparable<?> componentId, boolean toRepaintParent,
@@ -769,6 +863,7 @@ public class FadeTracker {
 			if (callback != null) {
 				callbackCallFadeEnded(callback, fadeKind);
 			}
+			this.globalCallbackCallFadeEnded(comp, componentId, fadeKind);
 			return -1;
 		}
 
@@ -781,6 +876,7 @@ public class FadeTracker {
 				else
 					comp.repaint();
 			}
+			this.globalCallbackCallFadeEnded(comp, componentId, fadeKind);
 			return -1;
 		}
 
@@ -797,12 +893,18 @@ public class FadeTracker {
 						fadeState.fadeStep, 2.0f);
 			fadeState.setCallback(callback);
 			this.addState(comp, componentId, fadeKind, fadeState);
+			this.globalCallbackCallFadeStarted(comp, componentId, fadeKind,
+					fadeState.getFadePosition());
 		} else {
 			if (fadeState.isFadingIn()) {
 				if (fadeState.getCallback() != null) {
-					fadeState.getCallback().fadeReversed(fadeKind, false,
-							fadeState.getFadePosition());
+					callbackCallFadeReversed(fadeState.getCallback(), fadeKind,
+							false, fadeState.getFadePosition());
+					// fadeState.getCallback().fadeReversed(fadeKind, false,
+					// fadeState.getFadePosition());
 				}
+				this.globalCallbackCallFadeReversed(comp, componentId,
+						fadeKind, false, fadeState.getFadePosition());
 			}
 			fadeState.setFadingIn(false);
 			fadeState.setCallback(callback);
@@ -826,9 +928,8 @@ public class FadeTracker {
 	 * @param toRepaintParent
 	 *            Indication whether the component parent should be repainted.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFade(Component comp, FadeKind fadeKind,
 			boolean isFadeIn, boolean toRepaintParent) {
@@ -849,9 +950,8 @@ public class FadeTracker {
 	 * @param callback
 	 *            Optional callback to be called on each fade cycle.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFade(Component comp, FadeKind fadeKind,
 			boolean isFadeIn, boolean toRepaintParent,
@@ -882,13 +982,12 @@ public class FadeTracker {
 	 * @param loopCount
 	 *            Loop count.
 	 * @param isLoopingReverse
-	 *            If <code>true</code>, when the fade value gets to the
-	 *            maximal value, the fade cycle will begin fade-out. Otherwise
-	 *            the fade cycle will begin from 0, continuing to fade-in.
+	 *            If <code>true</code>, when the fade value gets to the maximal
+	 *            value, the fade cycle will begin fade-out. Otherwise the fade
+	 *            cycle will begin from 0, continuing to fade-in.
 	 * @return ID of the fade instance. Guaranteed to be unique. Value
-	 *         <code>-1</code> signifies that there was no fade instance
-	 *         created (this may happen when the specified component is not
-	 *         visible).
+	 *         <code>-1</code> signifies that there was no fade instance created
+	 *         (this may happen when the specified component is not visible).
 	 */
 	public synchronized long trackFadeLooping(FadeKind fadeKind,
 			AnimationKind animationKind, Component comp,
@@ -912,6 +1011,7 @@ public class FadeTracker {
 						comp.repaint();
 				}
 			}
+			this.globalCallbackCallFadeEnded(comp, componentId, fadeKind);
 			return -1;
 		}
 
@@ -925,6 +1025,8 @@ public class FadeTracker {
 			fadeState.setCallback(callback);
 			fadeState.setLoopCount(loopCount);
 			this.addState(comp, componentId, fadeKind, fadeState);
+			this.globalCallbackCallFadeStarted(comp, componentId, fadeKind,
+					fadeState.getFadePosition());
 		} else {
 			fadeState.setLooping(true);
 			fadeState.setLoopingReverse(isLoopingReverse);
@@ -945,8 +1047,8 @@ public class FadeTracker {
 	 *            Component.
 	 * @param fadeKind
 	 *            Fade kind.
-	 * @return <code>true</code> if the specified component is being tracked
-	 *         by <code>this</code> tracker, <code>false</code> otherwise.
+	 * @return <code>true</code> if the specified component is being tracked by
+	 *         <code>this</code> tracker, <code>false</code> otherwise.
 	 */
 	public boolean isTracked(Component comp, FadeKind fadeKind) {
 		return this.isTracked(comp, null, fadeKind);
@@ -965,8 +1067,8 @@ public class FadeTracker {
 	 *            (where fade is performed on component "sub" parts).
 	 * @param fadeKind
 	 *            Fade kind.
-	 * @return <code>true</code> if the specified component is being tracked
-	 *         by <code>this</code> tracker, <code>false</code> otherwise.
+	 * @return <code>true</code> if the specified component is being tracked by
+	 *         <code>this</code> tracker, <code>false</code> otherwise.
 	 */
 	public boolean isTracked(Component comp, int componentId, FadeKind fadeKind) {
 		return this.isTracked(comp, new Integer(componentId), fadeKind);
@@ -986,8 +1088,8 @@ public class FadeTracker {
 	 *            component "sub" parts). May be <code>null</code>.
 	 * @param fadeKind
 	 *            Fade kind.
-	 * @return <code>true</code> if the specified component is being tracked
-	 *         by <code>this</code> tracker, <code>false</code> otherwise.
+	 * @return <code>true</code> if the specified component is being tracked by
+	 *         <code>this</code> tracker, <code>false</code> otherwise.
 	 */
 	public boolean isTracked(Component comp, Comparable<?> componentId,
 			FadeKind fadeKind) {
@@ -1017,8 +1119,8 @@ public class FadeTracker {
 	 *            If <code>true</code>, the returned value will be
 	 *            <code>true</code> only if the component is tracked <b>and</b>
 	 *            it is in the fade-in state.
-	 * @return <code>true</code> if the specified component is being tracked
-	 *         by <code>this</code> tracker, <code>false</code> otherwise.
+	 * @return <code>true</code> if the specified component is being tracked by
+	 *         <code>this</code> tracker, <code>false</code> otherwise.
 	 */
 	public boolean isTracked(Component comp, Comparable<?> componentId,
 			FadeKind fadeKind, boolean checkFadeIn) {
@@ -1040,7 +1142,7 @@ public class FadeTracker {
 
 	/**
 	 * Returns the fade cycle for the specified component. The result will be in
-	 * 0.0-10.0 range.
+	 * 0.0-1.0 range.
 	 * 
 	 * @param comp
 	 *            Component.
@@ -1051,13 +1153,13 @@ public class FadeTracker {
 	 *         {@link #isTracked(Component, org.jvnet.lafwidget.animation.FadeTracker.FadeKind)}
 	 *         returns <code>false</code>), value 0 (zero) is returned.
 	 */
-	public synchronized float getFade10(Component comp, FadeKind fadeKind) {
-		return this.getFade10(comp, null, fadeKind);
+	public synchronized float getFade(Component comp, FadeKind fadeKind) {
+		return this.getFade(comp, null, fadeKind);
 	}
 
 	/**
 	 * Returns the fade cycle for the specified component. The result will be in
-	 * 0.0-10.0 range.
+	 * 0.0-1.0 range.
 	 * 
 	 * @param comp
 	 *            Component.
@@ -1071,14 +1173,14 @@ public class FadeTracker {
 	 *         {@link #isTracked(Component, org.jvnet.lafwidget.animation.FadeTracker.FadeKind)}
 	 *         returns <code>false</code>), value 0 (zero) is returned.
 	 */
-	public synchronized float getFade10(Component comp, int componentId,
+	public synchronized float getFade(Component comp, int componentId,
 			FadeKind fadeKind) {
-		return this.getFade10(comp, new Integer(componentId), fadeKind);
+		return this.getFade(comp, new Integer(componentId), fadeKind);
 	}
 
 	/**
 	 * Returns the fade cycle for the specified component. The result will be in
-	 * 0.0-10.0 range.
+	 * 0.0-1.0 range.
 	 * 
 	 * @param comp
 	 *            Component.
@@ -1093,7 +1195,7 @@ public class FadeTracker {
 	 *         {@link #isTracked(Component, org.jvnet.lafwidget.animation.FadeTracker.FadeKind)}
 	 *         returns <code>false</code>), value 0 (zero) is returned.
 	 */
-	public synchronized float getFade10(Component comp,
+	public synchronized float getFade(Component comp,
 			Comparable<?> componentId, FadeKind fadeKind) {
 		if (fadeKind == null) {
 			throw new IllegalArgumentException("Can't pass null fadeKind");
@@ -1216,9 +1318,13 @@ public class FadeTracker {
 			for (Iterator<Map.Entry<ComponentId, FadeState>> itKind = mapComp
 					.entrySet().iterator(); itKind.hasNext();) {
 				Map.Entry<ComponentId, FadeState> entryKind = itKind.next();
+				ComponentId compId = entryKind.getKey();
 				FadeState state = entryKind.getValue();
 				if (state.getCallback() != null)
-					callbackCallFadeEnded(state.getCallback(), state.fadeKind);
+					this.callbackCallFadeEnded(state.getCallback(),
+							state.fadeKind);
+				this.globalCallbackCallFadeEnded(compId.component,
+						compId.subID, state.fadeKind);
 			}
 		}
 		this.trackedComponents.clear();
@@ -1253,11 +1359,12 @@ public class FadeTracker {
 				for (Iterator<Map.Entry<ComponentId, FadeState>> itKind = compFades
 						.entrySet().iterator(); itKind.hasNext();) {
 					Map.Entry<ComponentId, FadeState> entryKind = itKind.next();
+					ComponentId compId = entryKind.getKey();
 					FadeState state = entryKind.getValue();
 					if (fadeInstanceId == state.id) {
 						itKind.remove();
 						if (state.getCallback() != null) {
-							callbackCallFadeEnded(state.getCallback(),
+							this.callbackCallFadeEnded(state.getCallback(),
 									state.fadeKind);
 						} else {
 							if (state.isToRepaintParent()) {
@@ -1267,6 +1374,8 @@ public class FadeTracker {
 								entryKind.getKey().component.repaint();
 							}
 						}
+						this.globalCallbackCallFadeEnded(compId.component,
+								compId.subID, state.fadeKind);
 					}
 				}
 			}
@@ -1327,4 +1436,28 @@ public class FadeTracker {
 	public long getCurrLoopId() {
 		return currLoopId;
 	}
+
+	/**
+	 * Registers the specified application callback for tracking core fade
+	 * events.
+	 * 
+	 * @param callback
+	 *            Application callback for tracking core fade events.
+	 * @see FadeConfigurationManager#addGlobalFadeTrackerCallback(GlobalFadeTrackerCallback)
+	 * @see #removeGlobalCallback(GlobalFadeTrackerCallback)
+	 */
+	public void addGlobalCallback(GlobalFadeTrackerCallback callback) {
+		this.globalCallbackList.add(callback);
+	}
+
+	/**
+	 * Removes the specified application callback for tracking core fade events.
+	 * 
+	 * @param callback
+	 *            Application callback to remove.
+	 * @see #addGlobalFadeTrackerCallback(GlobalFadeTrackerCallback)
+	 */
+	public void removeGlobalCallback(GlobalFadeTrackerCallback callback) {
+		this.globalCallbackList.remove(callback);
+	}
 }
