@@ -33,7 +33,6 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
 import javax.swing.AbstractButton;
-import javax.swing.JComponent;
 
 import org.jvnet.lafwidget.LafWidgetAdapter;
 
@@ -42,7 +41,7 @@ import org.jvnet.lafwidget.LafWidgetAdapter;
  * 
  * @author Kirill Grouchnikov
  */
-public class GhostFadeWidget extends LafWidgetAdapter {
+public class GhostFadeWidget extends LafWidgetAdapter<AbstractButton> {
 	/**
 	 * Model change listener for ghost image effects.
 	 */
@@ -54,11 +53,6 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 	 */
 	protected PropertyChangeListener ghostPropertyListener;
 
-	/**
-	 * The corresponding button.
-	 */
-	protected AbstractButton button;
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -68,16 +62,6 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 		return false;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		this.button = (AbstractButton) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -85,7 +69,7 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void installDefaults() {
-		this.button.setRolloverEnabled(true);
+		this.jcomp.setRolloverEnabled(true);
 	}
 
 	/*
@@ -101,8 +85,8 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 						.getPropertyName())) {
 					if (ghostModelChangeListener != null)
 						ghostModelChangeListener.unregisterListeners();
-					ghostModelChangeListener = new GhostingListener(button,
-							button.getModel());
+					ghostModelChangeListener = new GhostingListener(jcomp,
+							jcomp.getModel());
 					ghostModelChangeListener.registerListeners();
 				}
 
@@ -115,9 +99,9 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 				// }
 			}
 		};
-		button.addPropertyChangeListener(this.ghostPropertyListener);
+		jcomp.addPropertyChangeListener(this.ghostPropertyListener);
 
-		this.ghostModelChangeListener = new GhostingListener(button, button
+		this.ghostModelChangeListener = new GhostingListener(jcomp, jcomp
 				.getModel());
 		this.ghostModelChangeListener.registerListeners();
 	}
@@ -129,7 +113,7 @@ public class GhostFadeWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		button.removePropertyChangeListener(this.ghostPropertyListener);
+		jcomp.removePropertyChangeListener(this.ghostPropertyListener);
 		this.ghostPropertyListener = null;
 
 		this.ghostModelChangeListener.unregisterListeners();
