@@ -34,7 +34,8 @@ import java.awt.image.BufferedImage;
 import java.util.LinkedHashMap;
 import java.util.Set;
 
-import javax.swing.*;
+import javax.swing.AbstractButton;
+import javax.swing.Icon;
 
 import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
@@ -103,9 +104,9 @@ public class GhostPaintingUtils {
 	 * Returns a scaled ghost image of the specified component.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param scaleFactor
-	 * 		Scale factor.
+	 *            Scale factor.
 	 * @return A scaled ghost image of the specified component.
 	 */
 	protected static synchronized BufferedImage getComponentGhostImage(
@@ -136,11 +137,11 @@ public class GhostPaintingUtils {
 	 * Returns a scaled ghost image of the specified icon.
 	 * 
 	 * @param comp
-	 * 		Component.
+	 *            Component.
 	 * @param icon
-	 * 		Icon.
+	 *            Icon.
 	 * @param scaleFactor
-	 * 		Scale factor.
+	 *            Scale factor.
 	 * @return A scaled ghost image of the specified icon.
 	 */
 	protected static synchronized BufferedImage getIconGhostImage(
@@ -171,9 +172,9 @@ public class GhostPaintingUtils {
 	 * Paints ghost images on the specified component.
 	 * 
 	 * @param mainComponent
-	 * 		Component.
+	 *            Component.
 	 * @param g
-	 * 		Graphics context.
+	 *            Graphics context.
 	 */
 	public static void paintGhostImages(Component mainComponent, Graphics g) {
 		if (!mainComponent.isShowing())
@@ -208,13 +209,6 @@ public class GhostPaintingUtils {
 				if (!comp.isDisplayable())
 					return;
 
-				// fix for issue 363. Since Window.getWindows() is available
-				// only in JDK 6.0, do not paint ghost images on another
-				// root pane
-				if (SwingUtilities.getRoot(comp) != SwingUtilities
-						.getRoot(mainComponent))
-					continue;
-
 				Rectangle compRect = comp.getBounds();
 				compRect.setLocation(comp.getLocationOnScreen());
 
@@ -227,17 +221,17 @@ public class GhostPaintingUtils {
 				compRect.height *= 2;
 
 				if (mainRect.intersects(compRect)) {
-					float fade10 = FadeTracker.getInstance().getFade10(comp,
+					float fade = FadeTracker.getInstance().getFade(comp,
 							null, FadeKind.GHOSTING_BUTTON_PRESS);
 					// 0.0 --> 0.3
-					// 10.0 --> 0.0
+					// 1.0 --> 0.0
 					double start = MAX_PRESS_GHOSTING_ALPHA - 0.0015
 							* compRect.getWidth();
 					float coef = Math.max((float) start,
 							MIN_PRESS_GHOSTING_ALPHA);
 					float opFactor = coef
-							* (1.0f - DECAY_FACTOR * fade10 / 10.0f);
-					double iFactor = 1.0 + fade10 / 10.0;
+							* (1.0f - DECAY_FACTOR * fade);
+					double iFactor = 1.0 + fade;
 
 					graphics.setComposite(TransitionLayout.getAlphaComposite(
 							mainComponent, opFactor));
@@ -278,13 +272,6 @@ public class GhostPaintingUtils {
 				if (!comp.isVisible())
 					continue;
 
-				// fix for issue 363. Since Window.getWindows() is available
-				// only in JDK 6.0, do not paint ghost images on another
-				// root pane
-				if (SwingUtilities.getRoot(comp) != SwingUtilities
-						.getRoot(mainComponent))
-					continue;
-
 				Rectangle compRect = comp.getBounds();
 				compRect.setLocation(comp.getLocationOnScreen());
 
@@ -297,7 +284,7 @@ public class GhostPaintingUtils {
 				compRect.height *= 2;
 
 				if (mainRect.intersects(compRect)) {
-					float fade10 = FadeTracker.getInstance().getFade10(comp,
+					float fade = FadeTracker.getInstance().getFade(comp,
 							null, FadeKind.GHOSTING_ICON_ROLLOVER);
 					// Rectangle bounds = comp.getBounds();
 					Icon icon = null;
@@ -310,7 +297,7 @@ public class GhostPaintingUtils {
 					}
 
 					if ((icon != null) && (iconRect != null)) {
-						double iFactor = 1.0 + fade10 / 10.0;
+						double iFactor = 1.0 + fade;
 						// double iWidth = icon.getIconWidth() * iFactor;
 						// double iHeight = icon.getIconHeight() * iFactor;
 						// BufferedImage iImage = LafWidgetUtilities
@@ -340,7 +327,7 @@ public class GhostPaintingUtils {
 						float coef = Math.max((float) start,
 								MIN_ICON_GHOSTING_ALPHA);
 						float opFactor = coef
-								* (1.0f - DECAY_FACTOR * fade10 / 10.0f);
+								* (1.0f - DECAY_FACTOR * fade);
 						graphics.setComposite(TransitionLayout
 								.getAlphaComposite(mainComponent, opFactor));
 
@@ -357,11 +344,11 @@ public class GhostPaintingUtils {
 	 * Paints the ghost icon inside the bounds of the specified button.
 	 * 
 	 * @param graphics
-	 * 		Graphics context.
+	 *            Graphics context.
 	 * @param b
-	 * 		Button.
+	 *            Button.
 	 * @param icon
-	 * 		Icon to paint.
+	 *            Icon to paint.
 	 */
 	public static void paintGhostIcon(Graphics2D graphics, AbstractButton b,
 			Icon icon) {
@@ -373,11 +360,11 @@ public class GhostPaintingUtils {
 	 * Paints the ghost icon inside the bounds of the specified button.
 	 * 
 	 * @param graphics
-	 * 		Graphics context.
+	 *            Graphics context.
 	 * @param b
-	 * 		Button.
+	 *            Button.
 	 * @param iconRectangle
-	 * 		Rectangle of the button icon.
+	 *            Rectangle of the button icon.
 	 */
 	public static void paintGhostIcon(Graphics2D graphics, AbstractButton b,
 			Rectangle iconRectangle) {
@@ -389,13 +376,13 @@ public class GhostPaintingUtils {
 	 * Paints the ghost icon inside the bounds of the specified button.
 	 * 
 	 * @param graphics
-	 * 		Graphics context.
+	 *            Graphics context.
 	 * @param b
-	 * 		Button.
+	 *            Button.
 	 * @param icon
-	 * 		Icon to paint.
+	 *            Icon to paint.
 	 * @param iconRectangle
-	 * 		Rectangle of the button icon.
+	 *            Rectangle of the button icon.
 	 */
 	public static void paintGhostIcon(Graphics2D graphics, AbstractButton b,
 			Icon icon, Rectangle iconRectangle) {
@@ -407,12 +394,12 @@ public class GhostPaintingUtils {
 
 		if (FadeTracker.getInstance().isTracked(b, null,
 				FadeKind.GHOSTING_ICON_ROLLOVER, true)) {
-			float fade10 = FadeTracker.getInstance().getFade10(b,
+			float fade = FadeTracker.getInstance().getFade(b,
 					FadeKind.GHOSTING_ICON_ROLLOVER);
-			// System.out.println(" --> " + fade10);
+			// System.out.println(" --> " + fade);
 			// double start = 0.5 - 0.35 * (icon.getIconWidth() - 16) / 48;
 			// float coef = Math.max((float) start, 0.15f);
-			// float opFactor = coef * (1.0f - DECAY_FACTOR*fade10 / 10.0f);
+			// float opFactor = coef * (1.0f - DECAY_FACTOR*fade);
 			// graphics.setComposite(TransitionLayout.getAlphaComposite(b,
 			// opFactor));
 			// System.out.println(opFactor);
@@ -421,7 +408,7 @@ public class GhostPaintingUtils {
 			// b.getClientProperty("icon.bounds");
 
 			if ((icon != null) && (iconRectangle != null)) {
-				double iFactor = 1.0 + fade10 / 10.0;
+				double iFactor = 1.0 + fade;
 				// double iWidth = icon.getIconWidth() * iFactor;
 				// double iHeight = icon.getIconHeight() * iFactor;
 				// BufferedImage iImage = LafWidgetUtilities.getBlankImage(
@@ -449,7 +436,7 @@ public class GhostPaintingUtils {
 						- (MAX_ICON_GHOSTING_ALPHA - MIN_ICON_GHOSTING_ALPHA)
 						* (iWidth - 16) / 48;
 				float coef = Math.max((float) start, MIN_ICON_GHOSTING_ALPHA);
-				float opFactor = coef * (1.0f - DECAY_FACTOR * fade10 / 10.0f);
+				float opFactor = coef * (1.0f - DECAY_FACTOR * fade);
 				graphics.setComposite(TransitionLayout.getAlphaComposite(b,
 						opFactor));
 
