@@ -33,7 +33,6 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
 import javax.swing.AbstractButton;
-import javax.swing.JComponent;
 
 import org.jvnet.lafwidget.LafWidgetAdapter;
 
@@ -42,7 +41,7 @@ import org.jvnet.lafwidget.LafWidgetAdapter;
  * 
  * @author Kirill Grouchnikov
  */
-public class IconGlowWidget extends LafWidgetAdapter {
+public class IconGlowWidget extends LafWidgetAdapter<AbstractButton> {
 	/**
 	 * Model change listener for glow effects.
 	 */
@@ -54,11 +53,6 @@ public class IconGlowWidget extends LafWidgetAdapter {
 	 */
 	protected PropertyChangeListener glowPropertyListener;
 
-	/**
-	 * The corresponding button.
-	 */
-	protected AbstractButton button;
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -68,16 +62,6 @@ public class IconGlowWidget extends LafWidgetAdapter {
 		return false;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		this.button = (AbstractButton) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -85,7 +69,7 @@ public class IconGlowWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void installDefaults() {
-		this.button.setRolloverEnabled(true);
+		this.jcomp.setRolloverEnabled(true);
 	}
 
 	/*
@@ -101,8 +85,8 @@ public class IconGlowWidget extends LafWidgetAdapter {
 						.getPropertyName())) {
 					if (glowModelChangeListener != null)
 						glowModelChangeListener.unregisterListeners();
-					glowModelChangeListener = new IconGlowListener(button,
-							button.getModel());
+					glowModelChangeListener = new IconGlowListener(jcomp, jcomp
+							.getModel());
 					glowModelChangeListener.registerListeners();
 				}
 
@@ -115,9 +99,9 @@ public class IconGlowWidget extends LafWidgetAdapter {
 				// }
 			}
 		};
-		button.addPropertyChangeListener(this.glowPropertyListener);
+		jcomp.addPropertyChangeListener(this.glowPropertyListener);
 
-		this.glowModelChangeListener = new IconGlowListener(button, button
+		this.glowModelChangeListener = new IconGlowListener(jcomp, jcomp
 				.getModel());
 		this.glowModelChangeListener.registerListeners();
 	}
@@ -129,7 +113,7 @@ public class IconGlowWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		button.removePropertyChangeListener(this.glowPropertyListener);
+		jcomp.removePropertyChangeListener(this.glowPropertyListener);
 		this.glowPropertyListener = null;
 
 		this.glowModelChangeListener.unregisterListeners();
