@@ -90,14 +90,14 @@ public class UiDelegateAugmenter {
 		 * Creates a new augmentor.
 		 * 
 		 * @param cv
-		 *            Class visitor to recreate the non-augmented methods.
+		 * 		Class visitor to recreate the non-augmented methods.
 		 * @param existingMethods
-		 *            Contains all method names.
+		 * 		Contains all method names.
 		 * @param existingFields
-		 *            Contains all field names.
+		 * 		Contains all field names.
 		 * @param methodsToAugment
-		 *            Contains all methods that will be augmented. Key is
-		 *            {@link String}, value is {@link Method}.
+		 * 		Contains all methods that will be augmented. Key is {@link
+		 * 		String}, value is {@link Method}.
 		 */
 		public AugmentClassAdapter(final ClassVisitor cv,
 				Set<String> existingMethods, Set<String> existingFields,
@@ -112,7 +112,7 @@ public class UiDelegateAugmenter {
 		 * (non-Javadoc)
 		 * 
 		 * @see org.objectweb.asm.ClassAdapter#visit(int, int, java.lang.String,
-		 *      java.lang.String, java.lang.String, java.lang.String[])
+		 * java.lang.String, java.lang.String, java.lang.String[])
 		 */
 		@Override
 		public void visit(final int version, final int access,
@@ -191,15 +191,14 @@ public class UiDelegateAugmenter {
 		 * Augments void UI method (w/o parameters).
 		 * 
 		 * @param toSynthOriginal
-		 *            Indication whether we need to create an empty (only call
-		 *            to super()) implementation.
+		 * 		Indication whether we need to create an empty (only call to
+		 * 		super()) implementation.
 		 * @param className
-		 *            Class name.
+		 * 		Class name.
 		 * @param superClassName
-		 *            Super class name (relevant for generating empty
-		 *            implementation).
+		 * 		Super class name (relevant for generating empty implementation).
 		 * @param methodName
-		 *            Method name.
+		 * 		Method name.
 		 */
 		public void augmentVoidMethod(boolean toSynthOriginal,
 				String className, String superClassName, String methodName) {
@@ -257,19 +256,18 @@ public class UiDelegateAugmenter {
 		 * Augments single-parameter UI method.
 		 * 
 		 * @param toSynthOriginal
-		 *            Indication whether we need to create an empty (only call
-		 *            to super()) implementation.
+		 * 		Indication whether we need to create an empty (only call to
+		 * 		super()) implementation.
 		 * @param className
-		 *            Class name.
+		 * 		Class name.
 		 * @param superClassName
-		 *            Super class name (relevant for generating empty
-		 *            implementation).
+		 * 		Super class name (relevant for generating empty implementation).
 		 * @param methodName
-		 *            Method name.
+		 * 		Method name.
 		 * @param functionDesc
-		 *            Function signature (using JNI style declaration). Example
-		 *            for <code>void installUI(JButton button)</code>:
-		 *            <code>(Ljavax/swing/JButton;)V</code>.
+		 * 		Function signature (using JNI style declaration). Example for
+		 * 		<code>void installUI(JButton button)</code>:
+		 * 		<code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentSingleParameterMethod(boolean toSynthOriginal,
 				String className, String superClassName, String methodName,
@@ -336,21 +334,20 @@ public class UiDelegateAugmenter {
 		}
 
 		/**
-		 * Augments the <code>installUI</code> method that is assumed to
-		 * always have a single parameter.
+		 * Augments the <code>installUI</code> method that is assumed to always
+		 * have a single parameter.
 		 * 
 		 * @param toSynthOriginal
-		 *            Indication whether we need to create an empty (only call
-		 *            to super()) implementation.
+		 * 		Indication whether we need to create an empty (only call to
+		 * 		super()) implementation.
 		 * @param className
-		 *            Class name.
+		 * 		Class name.
 		 * @param superClassName
-		 *            Super class name (relevant for generating empty
-		 *            implementation).
+		 * 		Super class name (relevant for generating empty implementation).
 		 * @param functionDesc
-		 *            Function signature (using JNI style declaration). Example
-		 *            for <code>void installUI(JButton button)</code>:
-		 *            <code>(Ljavax/swing/JButton;)V</code>.
+		 * 		Function signature (using JNI style declaration). Example for
+		 * 		<code>void installUI(JButton button)</code>:
+		 * 		<code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentInstallUIMethod(boolean toSynthOriginal,
 				String className, String superClassName, String functionDesc) {
@@ -423,17 +420,16 @@ public class UiDelegateAugmenter {
 		 * have two parameters.
 		 * 
 		 * @param toSynthOriginal
-		 *            Indication whether we need to create an empty (only call
-		 *            to super()) implementation.
+		 * 		Indication whether we need to create an empty (only call to
+		 * 		super()) implementation.
 		 * @param className
-		 *            Class name.
+		 * 		Class name.
 		 * @param superClassName
-		 *            Super class name (relevant for generating empty
-		 *            implementation).
+		 * 		Super class name (relevant for generating empty implementation).
 		 * @param functionDesc
-		 *            Function signature (using JNI style declaration). Example
-		 *            for <code>void installUI(JButton button)</code>:
-		 *            <code>(Ljavax/swing/JButton;)V</code>.
+		 * 		Function signature (using JNI style declaration). Example for
+		 * 		<code>void installUI(JButton button)</code>:
+		 * 		<code>(Ljavax/swing/JButton;)V</code>.
 		 */
 		public void augmentUpdateMethod(boolean toSynthOriginal,
 				String className, String superClassName, String functionDesc) {
@@ -457,7 +453,8 @@ public class UiDelegateAugmenter {
 			}
 
 			// MethodVisitor mv = this.cv.visitMethod(ACC_PUBLIC, "update",
-			// "(Ljava/awt/Graphics;Ljavax/swing/JComponent;)V", null, null);
+			// "(Ljava/awt/Graphics;Ljavax/swing/JComponent;)V", null,
+			// null);
 			// mv.visitCode();
 			// mv.visitVarInsn(ALOAD, 1);
 			// mv.visitTypeInsn(CHECKCAST, "java/awt/Graphics2D");
@@ -466,30 +463,39 @@ public class UiDelegateAugmenter {
 			// mv.visitMethodInsn(INVOKEVIRTUAL, "java/awt/Graphics2D",
 			// "getComposite", "()Ljava/awt/Composite;");
 			// mv.visitVarInsn(ASTORE, 4);
-			// mv.visitVarInsn(ALOAD, 2);
-			// mv.visitLdcInsn("lafwidgets.layout.alpha");
-			// mv.visitMethodInsn(INVOKEVIRTUAL, "javax/swing/JComponent",
-			// "getClientProperty", "(Ljava/lang/Object;)Ljava/lang/Object;");
-			// mv.visitVarInsn(ASTORE, 5);
-			// mv.visitVarInsn(ALOAD, 5);
-			// mv.visitTypeInsn(INSTANCEOF, "java/lang/Float");
+			// mv.visitInsn(FCONST_1);
+			// mv.visitVarInsn(FSTORE, 5);
+			// mv.visitVarInsn(ALOAD, 4);
+			// mv.visitTypeInsn(INSTANCEOF, "java/awt/AlphaComposite");
 			// Label l0 = new Label();
 			// mv.visitJumpInsn(IFEQ, l0);
-			// mv.visitVarInsn(ALOAD, 3);
+			// mv.visitVarInsn(ALOAD, 4);
+			// mv.visitTypeInsn(CHECKCAST, "java/awt/AlphaComposite");
+			// mv.visitVarInsn(ASTORE, 6);
+			// mv.visitVarInsn(ALOAD, 6);
+			// mv.visitMethodInsn(INVOKEVIRTUAL, "java/awt/AlphaComposite",
+			// "getRule", "()I");
 			// mv.visitInsn(ICONST_3);
-			// mv.visitVarInsn(ALOAD, 5);
-			// mv.visitTypeInsn(CHECKCAST, "java/lang/Float");
-			// mv.visitMethodInsn(INVOKEVIRTUAL, "java/lang/Float",
-			// "floatValue", "()F");
-			// mv.visitMethodInsn(INVOKESTATIC, "java/awt/AlphaComposite",
-			// "getInstance", "(IF)Ljava/awt/AlphaComposite;");
+			// mv.visitJumpInsn(IF_ICMPNE, l0);
+			// mv.visitVarInsn(ALOAD, 6);
+			// mv.visitMethodInsn(INVOKEVIRTUAL, "java/awt/AlphaComposite",
+			// "getAlpha", "()F");
+			// mv.visitVarInsn(FSTORE, 5);
+			// mv.visitLabel(l0);
+			// mv.visitVarInsn(ALOAD, 3);
+			// mv.visitVarInsn(ALOAD, 2);
+			// mv.visitVarInsn(FLOAD, 5);
+			// mv.visitMethodInsn(INVOKESTATIC,
+			// "org/jvnet/lafwidget/layout/TransitionLayout",
+			// "getAlphaComposite",
+			// "(Ljava/awt/Component;F)Ljava/awt/Composite;");
 			// mv.visitMethodInsn(INVOKEVIRTUAL, "java/awt/Graphics2D",
 			// "setComposite", "(Ljava/awt/Composite;)V");
-			// mv.visitLabel(l0);
 			// mv.visitVarInsn(ALOAD, 3);
 			// mv.visitMethodInsn(INVOKESTATIC,
 			// "org/jvnet/lafwidget/utils/RenderingUtils",
-			// "installDesktopHints", "(Ljava/awt/Graphics2D;)Ljava/util/Map;");
+			// "installDesktopHints",
+			// "(Ljava/awt/Graphics2D;)Ljava/util/Map;");
 			// mv.visitVarInsn(ASTORE, 6);
 			// mv.visitVarInsn(ALOAD, 0);
 			// mv.visitVarInsn(ALOAD, 3);
@@ -553,10 +559,12 @@ public class UiDelegateAugmenter {
 			mv.visitMethodInsn(INVOKEVIRTUAL, "java/awt/Graphics2D",
 					"setComposite", "(Ljava/awt/Composite;)V");
 			mv.visitVarInsn(ALOAD, 3);
-			mv.visitMethodInsn(INVOKESTATIC,
-					"org/jvnet/lafwidget/utils/RenderingUtils",
-					"installDesktopHints",
-					"(Ljava/awt/Graphics2D;)Ljava/util/Map;");
+			mv.visitVarInsn(ALOAD, 2);
+			mv
+					.visitMethodInsn(INVOKESTATIC,
+							"org/jvnet/lafwidget/utils/RenderingUtils",
+							"installDesktopHints",
+							"(Ljava/awt/Graphics2D;Ljava/awt/Component;)Ljava/util/Map;");
 			mv.visitVarInsn(ASTORE, 6);
 			mv.visitVarInsn(ALOAD, 0);
 			mv.visitVarInsn(ALOAD, 3);
@@ -586,8 +594,8 @@ public class UiDelegateAugmenter {
 		 * (non-Javadoc)
 		 * 
 		 * @see org.objectweb.asm.ClassAdapter#visitMethod(int,
-		 *      java.lang.String, java.lang.String, java.lang.String,
-		 *      java.lang.String[])
+		 * java.lang.String, java.lang.String, java.lang.String,
+		 * java.lang.String[])
 		 */
 		@Override
 		public MethodVisitor visitMethod(final int access, final String name,
@@ -615,11 +623,11 @@ public class UiDelegateAugmenter {
 	 * Augments a single class with additional UI behaviour.
 	 * 
 	 * @param dir
-	 *            Root directory for the library that contains the class.
+	 * 		Root directory for the library that contains the class.
 	 * @param name
-	 *            Fully-qualified class name.
+	 * 		Fully-qualified class name.
 	 * @throws AugmentException
-	 *             If the augmentation process failed.
+	 * 		If the augmentation process failed.
 	 */
 	protected synchronized void augmentClass(String dir, final String name) {
 		if (this.isVerbose)
@@ -693,7 +701,7 @@ public class UiDelegateAugmenter {
 			}
 		}
 
-		// See if the 'lafWidgets' field is already defined. In this
+		// See if the' lafWidgets' field is already defined. In this
 		// case the class is *not* augmented
 		if (existingFields.contains("lafWidgets")) {
 			if (this.isVerbose)
@@ -760,16 +768,15 @@ public class UiDelegateAugmenter {
 	 * Processes a single file or a directory, augmenting all relevant classes.
 	 * 
 	 * @param toStrip
-	 *            The leading prefix to strip from the file names. Is used to
-	 *            create fully-qualified class name.
+	 * 		The leading prefix to strip from the file names. Is used to create
+	 * 		fully-qualified class name.
 	 * @param file
-	 *            File resource (can point to a single file or to a directory).
+	 * 		File resource (can point to a single file or to a directory).
 	 * @param pattern
-	 *            Pattern to apply to the file name (of the single file). If the
-	 *            file name matches the pattern, the relevant class is
-	 *            augmented.
+	 * 		Pattern to apply to the file name (of the single file). If the file
+	 * 		name matches the pattern, the relevant class is augmented.
 	 * @throws AugmentException
-	 *             If the augmentation process failed.
+	 * 		If the augmentation process failed.
 	 */
 	public void process(String toStrip, File file, Pattern pattern)
 			throws AugmentException {
@@ -794,7 +801,7 @@ public class UiDelegateAugmenter {
 	 * Sets the verbosity.
 	 * 
 	 * @param isVerbose
-	 *            New value for augmentation process verbosity.
+	 * 		New value for augmentation process verbosity.
 	 */
 	public void setVerbose(boolean isVerbose) {
 		this.isVerbose = isVerbose;
