@@ -34,7 +34,8 @@ import java.awt.event.MouseEvent;
 import java.awt.image.BufferedImage;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.*;
+import java.util.HashMap;
+import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.JInternalFrame.JDesktopIcon;
@@ -49,12 +50,8 @@ import org.jvnet.lafwidget.*;
  * 
  * @author Kirill Grouchnikov
  */
-public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
-	/**
-	 * The associated desktop icon.
-	 */
-	protected JDesktopIcon desktopIcon;
-
+public class DesktopIconHoverPreviewWidget extends
+		LafWidgetAdapter<JDesktopIcon> {
 	/**
 	 * The component that initiates the desktop icon preview (when the mouse
 	 * hover above it).
@@ -72,16 +69,6 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	// private static WeakHashMap snapshots = new WeakHashMap();
 	private BufferedImage snapshot;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.desktopIcon = (JDesktopIcon) jcomp;
-	}
-
 	/**
 	 * Preview window (activated on hover).
 	 */
@@ -103,6 +90,7 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	 * @author Kirill Grouchnikov.
 	 */
 	protected class TitleMouseHandler extends MouseInputAdapter {
+		@Override
 		public void mouseEntered(MouseEvent e) {
 			if (DesktopIconHoverPreviewWidget.this.isInDrag)
 				return;
@@ -126,21 +114,25 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 			}
 		}
 
+		@Override
 		public void mouseExited(MouseEvent e) {
 			DesktopIconHoverPreviewWidget.this.isInDrag = false;
 			DesktopIconHoverPreviewWidget.this.previewWindow.dispose();// setVisible(false);
 		}
 
+		@Override
 		public void mousePressed(MouseEvent e) {
 			DesktopIconHoverPreviewWidget.this.previewWindow.dispose();// setVisible(false);
 		}
 
+		@Override
 		public void mouseReleased(MouseEvent e) {
 			DesktopIconHoverPreviewWidget.this.isInDrag = false;
 			DesktopIconHoverPreviewWidget.this.syncPreviewWindow(true);
 			DesktopIconHoverPreviewWidget.this.previewWindow.setVisible(true);
 		}
 
+		@Override
 		public void mouseDragged(MouseEvent e) {
 			DesktopIconHoverPreviewWidget.this.isInDrag = true;
 			if (DesktopIconHoverPreviewWidget.this.previewWindow.isVisible()) {
@@ -155,6 +147,7 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#installComponents()
 	 */
+	@Override
 	public void installComponents() {
 		this.previewWindow = new JWindow();
 		this.previewWindow.getContentPane().setLayout(new BorderLayout());
@@ -165,23 +158,23 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#installListeners()
 	 */
+	@Override
 	public void installListeners() {
 		this.internalFramePropertyListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
 				if ("ancestor".equals(evt.getPropertyName())) {
-					updateSnapshot(DesktopIconHoverPreviewWidget.this.desktopIcon
-							.getInternalFrame());
+					updateSnapshot(jcomp.getInternalFrame());
 				}
 			}
 		};
-		this.desktopIcon.getInternalFrame().addPropertyChangeListener(
+		jcomp.getInternalFrame().addPropertyChangeListener(
 				this.internalFramePropertyListener);
 
 		this.titleMouseHandler = new TitleMouseHandler();
 
 		LafWidgetSupport lafSupport = LafWidgetRepository.getRepository()
 				.getLafSupport();
-		this.compToHover = lafSupport.getComponentForHover(this.desktopIcon);
+		this.compToHover = lafSupport.getComponentForHover(jcomp);
 
 		if (this.compToHover != null) {
 			this.compToHover.addMouseMotionListener(this.titleMouseHandler);
@@ -194,8 +187,9 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#uninstallListeners()
 	 */
+	@Override
 	public void uninstallListeners() {
-		this.desktopIcon.getInternalFrame().removePropertyChangeListener(
+		jcomp.getInternalFrame().removePropertyChangeListener(
 				this.internalFramePropertyListener);
 		this.internalFramePropertyListener = null;
 
@@ -214,8 +208,8 @@ public class DesktopIconHoverPreviewWidget extends LafWidgetAdapter {
 	 */
 	private void syncPreviewWindow(boolean toShow) {
 		if (toShow) {
-			int x = this.desktopIcon.getLocationOnScreen().x;
-			int y = this.desktopIcon.getLocationOnScreen().y;
+			int x = jcomp.getLocationOnScreen().x;
+			int y = jcomp.getLocationOnScreen().y;
 
 			this.previewWindow.setLocation(x, y
 					- this.previewWindow.getHeight());
