@@ -240,9 +240,9 @@ public class TransitionLayout implements LayoutManager {
 					.getClientProperty(SHOWING))
 					&& !FadeTracker.getInstance().isTracked(jc, COMPONENT_FADE);
 			boolean isShowing = /*
-			 * ((newBounds.width > 0) && (newBounds.height >
-			 * 0) &&
-			 */jc.isVisible()
+								 * ((newBounds.width > 0) && (newBounds.height >
+								 * 0) &&
+								 */jc.isVisible()
 					&& (!Boolean.TRUE.equals(jc.getClientProperty(LIMBO)));
 			// || added.contains(c);
 
@@ -283,7 +283,7 @@ public class TransitionLayout implements LayoutManager {
 					// }
 					this.animationStarted();
 					FadeTracker.getInstance().trackFadeIn(COMPONENT_BOUNDS, jc,
-							false, new EDTFadeTrackerAdapter() {
+							false, new UIThreadFadeTrackerAdapter() {
 								@Override
 								public void fadeEnded(FadeKind fadeKind) {
 									if (hasFades) {
@@ -304,22 +304,18 @@ public class TransitionLayout implements LayoutManager {
 
 								@Override
 								public void fadePerformed(FadeKind fadeKind,
-										final float fade10) {
-									// if (fade10 == 1.0)
+										final float fade) {
+									// if (fade == 1.0)
 									Rectangle currBounds = new Rectangle(
-											(int) (oldBounds.x + fade10
-													* (newBounds.x - oldBounds.x)
-													/ 10.0),
-											(int) (oldBounds.y + fade10
-													* (newBounds.y - oldBounds.y)
-													/ 10.0),
-											(int) (oldBounds.width + fade10
-													* (newBounds.width - oldBounds.width)
-													/ 10.0),
-											(int) (oldBounds.height + fade10
-													* (newBounds.height - oldBounds.height)
-													/ 10.0));
-									// System.out.println(fade10 + ":"
+											(int) (oldBounds.x + fade
+													* (newBounds.x - oldBounds.x)),
+											(int) (oldBounds.y + fade
+													* (newBounds.y - oldBounds.y)),
+											(int) (oldBounds.width + fade
+													* (newBounds.width - oldBounds.width)),
+											(int) (oldBounds.height + fade
+													* (newBounds.height - oldBounds.height)));
+									// System.out.println(fade + ":"
 									// + currBounds + ":" + oldBounds
 									// + ":" + newBounds);
 									jc.setBounds(currBounds);
@@ -333,7 +329,7 @@ public class TransitionLayout implements LayoutManager {
 										// ==
 										// null)) {
 										double coef = 1 + 2.0 * Math
-												.abs(fade10 / 10.0 - 0.5);
+												.abs(fade - 0.5);
 										double alpha = 0.5 + (0.25 * coef * coef) / 2.0;
 										setAlpha(jc, new Float(
 												getCompositeAlpha(jc
@@ -360,7 +356,7 @@ public class TransitionLayout implements LayoutManager {
 				jc.setVisible(true);
 				this.animationStarted();
 				FadeTracker.getInstance().trackFadeIn(COMPONENT_FADE, jc,
-						false, new EDTFadeTrackerAdapter() {
+						false, new UIThreadFadeTrackerAdapter() {
 							@Override
 							public void fadeEnded(FadeKind fadeKind) {
 								float parentAlpha = getCompositeAlpha(jc
@@ -379,14 +375,13 @@ public class TransitionLayout implements LayoutManager {
 
 							@Override
 							public void fadePerformed(FadeKind fadeKind,
-									final float fade10) {
+									final float fade) {
 								setAlpha(jc, new Float(getCompositeAlpha(jc
 										.getParent())
-										* fade10 / 10.0), new Float(
-										fade10 / 10.0), true);
+										* fade), new Float(fade), true);
 								// jc.putClientProperty(ALPHA, new
 								// Float(
-								// fade10 / 10.0));
+								// fade));
 								// if (jc instanceof JDesktopPane)
 								// System.out.println(jc.getClass().getName()
 								// + " --> "
@@ -412,7 +407,7 @@ public class TransitionLayout implements LayoutManager {
 				jc.setVisible(true);
 				this.animationStarted();
 				FadeTracker.getInstance().trackFadeOut(COMPONENT_FADE, jc,
-						false, new EDTFadeTrackerAdapter() {
+						false, new UIThreadFadeTrackerAdapter() {
 							@Override
 							public void fadeEnded(FadeKind fadeKind) {
 								restoreOpaque(jc, opacity, true);
@@ -431,14 +426,13 @@ public class TransitionLayout implements LayoutManager {
 
 							@Override
 							public void fadePerformed(FadeKind fadeKind,
-									final float fade10) {
+									final float fade) {
 								setAlpha(jc, new Float(getCompositeAlpha(jc
 										.getParent())
-										* fade10 / 10.0), new Float(
-										fade10 / 10.0), true);
+										* fade), new Float(fade), true);
 								// jc.putClientProperty(ALPHA, new
 								// Float(
-								// fade10 / 10.0));
+								// fade));
 								fireEvent(jc,
 										TransitionLayoutEvent.CHILD_FADING_OUT);
 								repaint(jc);
@@ -809,15 +803,16 @@ public class TransitionLayout implements LayoutManager {
 	public static Composite getAlphaComposite(Component c, float translucency,
 			Graphics g) {
 		float xFactor = 1.0f;
-		if ((g != null) && (g instanceof Graphics2D)) {
+		if (g instanceof Graphics2D) {
 			Graphics2D g2d = (Graphics2D) g;
-			Composite c2 = g2d.getComposite();
-			if (c2 instanceof AlphaComposite) {
-				AlphaComposite ac = (AlphaComposite) c2;
+			Composite existingComposite = g2d.getComposite();
+			if (existingComposite instanceof AlphaComposite) {
+				AlphaComposite ac = (AlphaComposite) existingComposite;
 				if (ac.getRule() == AlphaComposite.SRC_OVER)
 					xFactor = ac.getAlpha();
 			}
 		}
+		float finalAlpha = translucency * xFactor;
 		if (c instanceof JComponent) {
 			Object alphaObj = ((JComponent) c)
 					.getClientProperty(TransitionLayout.ALPHA);
@@ -825,15 +820,11 @@ public class TransitionLayout implements LayoutManager {
 			if (alphaObj != null) {
 				transitionAlpha = ((Float) alphaObj).floatValue();
 			}
-			return AlphaComposite.getInstance(AlphaComposite.SRC_OVER,
-					translucency * transitionAlpha * xFactor);
-		} else {
-			if ((translucency == 1.0f) && (xFactor == 1.0f))
-				return AlphaComposite.SrcOver;
-			else
-				return AlphaComposite.getInstance(AlphaComposite.SRC_OVER,
-						translucency * xFactor);
+			finalAlpha *= transitionAlpha;
 		}
+		if (finalAlpha == 1.0f)
+			return AlphaComposite.SrcOver;
+		return AlphaComposite.SrcOver.derive(finalAlpha);
 	}
 
 	public static Composite getAlphaComposite(Component c, float translucency) {
@@ -877,9 +868,9 @@ public class TransitionLayout implements LayoutManager {
 	 * component background during the transition fade animations. Note that
 	 * during the transition fades, the components are marked as non-opaque so
 	 * that Swing will handle them correctly. This means that calling
-	 * {@link Component#isOpaque()} will return <code>false</code>,
-	 * incorrectly signifying to the painting code that the background fill
-	 * should be omitted.
+	 * {@link Component#isOpaque()} will return <code>false</code>, incorrectly
+	 * signifying to the painting code that the background fill should be
+	 * omitted.
 	 * 
 	 * @param c
 	 *            Component.
