@@ -36,7 +36,6 @@ import java.beans.PropertyChangeListener;
 import java.util.*;
 
 import javax.swing.*;
-import javax.swing.JInternalFrame.JDesktopIcon;
 
 import org.jvnet.lafwidget.*;
 
@@ -45,12 +44,8 @@ import org.jvnet.lafwidget.*;
  * 
  * @author Kirill Grouchnikov
  */
-public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
-	/**
-	 * The associated menu bar.
-	 */
-	protected JMenuBar jmb;
-
+public class MenuSearchWidget extends LafWidgetAdapter<JMenuBar> implements
+		Resettable {
 	/**
 	 * Boolean flag to prevent infinite loop. Maybe need to use something more
 	 * elegant.
@@ -109,9 +104,9 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 			int iconDim = support.getLookupIconSize();
 			int buttonDim = support.getLookupButtonSize();
 			Icon searchIcon = (support == null) ? LafWidgetUtilities
-					.getSearchIcon(iconDim, jmb.getComponentOrientation()
+					.getSearchIcon(iconDim, jcomp.getComponentOrientation()
 							.isLeftToRight()) : support.getSearchIcon(iconDim,
-					jmb.getComponentOrientation());
+					jcomp.getComponentOrientation());
 			this.searchButton = new JToggleButton(searchIcon);
 			this.searchButton.setPreferredSize(new Dimension(buttonDim,
 					buttonDim));
@@ -156,7 +151,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 							public void run() {
 								SearchPanel.this.removeAll();
 								SearchPanel.this.repaint();
-								jmb.revalidate();
+								jcomp.revalidate();
 							}
 						});
 					}
@@ -224,7 +219,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 						count++;
 					}
 					SearchPanel.this.repaint();
-					jmb.revalidate();
+					jcomp.revalidate();
 				}
 			});
 		}
@@ -243,8 +238,8 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 
 			LinkedList<JMenu> currentPath = new LinkedList<JMenu>();
 
-			for (int i = 0; i < jmb.getComponentCount(); i++) {
-				Component component = jmb.getComponent(i);
+			for (int i = 0; i < jcomp.getComponentCount(); i++) {
+				Component component = jcomp.getComponent(i);
 				if (component instanceof JMenu) {
 					JMenu menu = (JMenu) component;
 					this.checkMenu(currentPath, menu, searchPattern, result);
@@ -277,7 +272,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 				LinkedList<SearchResult> matchingResults) {
 			String menuItemText = menuItem.getText();
 			if (menuItemText.toLowerCase().indexOf(searchPattern) >= 0) {
-				matchingResults.addLast(new SearchResult(jmb, currentPath,
+				matchingResults.addLast(new SearchResult(jcomp, currentPath,
 						menuItem));
 			}
 			if (menuItem instanceof JMenu) {
@@ -489,140 +484,135 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 		return result;
 	}
 
-	/**
-	 * Hides search panels recursively on the specified component.
-	 * 
-	 * @param comp
-	 *            Component.
-	 * @param toRepaint
-	 *            Indication whether the relevant menu bars should be repainted.
-	 */
-	private static void hideSearchPanels(Component comp, final boolean toRepaint) {
-		if (comp instanceof JFrame) {
-			JFrame jf = (JFrame) comp;
-			if (jf.getRootPane() != null) {
-				JMenuBar menuBar = jf.getJMenuBar();
-				if (menuBar != null) {
-					for (int j = 0; j < menuBar.getComponentCount(); j++) {
-						if (menuBar.getComponent(j) instanceof SearchPanel) {
-							SearchPanel sPanel = (SearchPanel) menuBar
-									.getComponent(j);
-							menuBar.remove(sPanel);
-							if (toRepaint)
-								menuBar.repaint();
-							break;
-						}
-					}
-				}
-			}
-		}
+	// /**
+	// * Hides search panels recursively on the specified component.
+	// *
+	// * @param comp
+	// * Component.
+	// * @param toRepaint
+	// * Indication whether the relevant menu bars should be repainted.
+	// */
+	// private static void hideSearchPanels(Component comp, final boolean toRepaint)
+	// {
+	// if (comp instanceof JFrame) {
+	// JFrame jf = (JFrame) comp;
+	// if (jf.getRootPane() != null) {
+	// JMenuBar menuBar = jf.getJMenuBar();
+	// if (menuBar != null) {
+	// for (int j = 0; j < menuBar.getComponentCount(); j++) {
+	// if (menuBar.getComponent(j) instanceof SearchPanel) {
+	// SearchPanel sPanel = (SearchPanel) menuBar
+	// .getComponent(j);
+	// menuBar.remove(sPanel);
+	// if (toRepaint)
+	// menuBar.repaint();
+	// break;
+	// }
+	// }
+	// }
+	// }
+	// }
+	//
+	// if (comp instanceof JInternalFrame) {
+	// JInternalFrame jif = (JInternalFrame) comp;
+	// if (jif.getRootPane() != null) {
+	// JMenuBar menuBar = jif.getJMenuBar();
+	// if (menuBar != null) {
+	// for (int j = 0; j < menuBar.getComponentCount(); j++) {
+	// if (menuBar.getComponent(j) instanceof SearchPanel) {
+	// SearchPanel sPanel = (SearchPanel) menuBar
+	// .getComponent(j);
+	// menuBar.remove(sPanel);
+	// if (toRepaint)
+	// menuBar.repaint();
+	// break;
+	// }
+	// }
+	// }
+	// }
+	// }
+	//
+	// if (comp instanceof Container) {
+	// Container cont = (Container) comp;
+	// for (int i = 0; i < cont.getComponentCount(); i++) {
+	// Component child = cont.getComponent(i);
+	// if (child instanceof JDesktopIcon)
+	// child = ((JDesktopIcon) child).getInternalFrame();
+	// hideSearchPanels(child, toRepaint);
+	// }
+	// }
+	// }
+	//
+	// /**
+	// * Hides search panels on all menu bars (both JFrames and JInternalFrames).
+	// *
+	// * @param toRepaint
+	// * Indication whether the relevant menu bars should be repainted.
+	// */
+	// public static void hideSearchPanels(final boolean toRepaint) {
+	// SwingUtilities.invokeLater(new Runnable() {
+	// public void run() {
+	// Frame[] frames = Frame.getFrames();
+	// for (int i = 0; i < frames.length; i++) {
+	// hideSearchPanels(frames[i], toRepaint);
+	// }
+	// };
+	// });
+	// }
 
-		if (comp instanceof JInternalFrame) {
-			JInternalFrame jif = (JInternalFrame) comp;
-			if (jif.getRootPane() != null) {
-				JMenuBar menuBar = jif.getJMenuBar();
-				if (menuBar != null) {
-					for (int j = 0; j < menuBar.getComponentCount(); j++) {
-						if (menuBar.getComponent(j) instanceof SearchPanel) {
-							SearchPanel sPanel = (SearchPanel) menuBar
-									.getComponent(j);
-							menuBar.remove(sPanel);
-							if (toRepaint)
-								menuBar.repaint();
-							break;
-						}
-					}
-				}
-			}
-		}
-
-		if (comp instanceof Container) {
-			Container cont = (Container) comp;
-			for (int i = 0; i < cont.getComponentCount(); i++) {
-				Component child = cont.getComponent(i);
-				if (child instanceof JDesktopIcon)
-					child = ((JDesktopIcon) child).getInternalFrame();
-				hideSearchPanels(child, toRepaint);
-			}
-		}
-	}
-
-	/**
-	 * Hides search panels on all menu bars (both JFrames and JInternalFrames).
-	 * 
-	 * @param toRepaint
-	 *            Indication whether the relevant menu bars should be repainted.
-	 */
-	public static void hideSearchPanels(final boolean toRepaint) {
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				Frame[] frames = Frame.getFrames();
-				for (int i = 0; i < frames.length; i++) {
-					hideSearchPanels(frames[i], toRepaint);
-				}
-			};
-		});
-	}
-
-	/**
-	 * Shows search panels on all descendant internal frames of the specified
-	 * component.
-	 * 
-	 * @param comp
-	 *            A component.
-	 */
-	protected static void showSearchPanels(Component comp) {
-		if (comp instanceof JDesktopPane) {
-			JDesktopPane desktop = (JDesktopPane) comp;
-			JInternalFrame[] iFrames = desktop.getAllFrames();
-			for (int i = 0; i < iFrames.length; i++) {
-				JInternalFrame jif = iFrames[i];
-				if (jif.getRootPane() != null) {
-					JMenuBar menuBar = jif.getJMenuBar();
-					if (menuBar != null)
-						SwingUtilities.updateComponentTreeUI(menuBar);
-				}
-			}
-			return;
-		}
-		if (comp instanceof Container) {
-			Container cont = (Container) comp;
-			for (int i = 0; i < cont.getComponentCount(); i++) {
-				MenuSearchWidget.showSearchPanels(cont.getComponent(i));
-			}
-		}
-	}
-
-	/**
-	 * Shows search panels on all menu bars (both JFrames and JInternalFrames).
-	 */
-	public static void showSearchPanels() {
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				Frame[] frames = Frame.getFrames();
-				for (int i = 0; i < frames.length; i++) {
-					Frame frame = frames[i];
-
-					if (frame instanceof JFrame) {
-						JFrame jf = (JFrame) frame;
-						if (jf.getRootPane() != null) {
-							JMenuBar menuBar = jf.getJMenuBar();
-							if (menuBar != null)
-								SwingUtilities.updateComponentTreeUI(menuBar);
-						}
-					}
-					// fix for defect 134 - menubars on internal frames
-					MenuSearchWidget.showSearchPanels(frame);
-				}
-			};
-		});
-	}
-
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.jmb = (JMenuBar) jcomp;
-	}
+	// /**
+	// * Shows search panels on all descendant internal frames of the specified
+	// * component.
+	// *
+	// * @param comp
+	// * A component.
+	// */
+	// protected static void showSearchPanels(Component comp) {
+	// if (comp instanceof JDesktopPane) {
+	// JDesktopPane desktop = (JDesktopPane) comp;
+	// JInternalFrame[] iFrames = desktop.getAllFrames();
+	// for (int i = 0; i < iFrames.length; i++) {
+	// JInternalFrame jif = iFrames[i];
+	// if (jif.getRootPane() != null) {
+	// JMenuBar menuBar = jif.getJMenuBar();
+	// if (menuBar != null)
+	// SwingUtilities.updateComponentTreeUI(menuBar);
+	// }
+	// }
+	// return;
+	// }
+	// if (comp instanceof Container) {
+	// Container cont = (Container) comp;
+	// for (int i = 0; i < cont.getComponentCount(); i++) {
+	// MenuSearchWidget.showSearchPanels(cont.getComponent(i));
+	// }
+	// }
+	// }
+	//
+	// /**
+	// * Shows search panels on all menu bars (both JFrames and JInternalFrames).
+	// */
+	// public static void showSearchPanels() {
+	// SwingUtilities.invokeLater(new Runnable() {
+	// public void run() {
+	// Frame[] frames = Frame.getFrames();
+	// for (int i = 0; i < frames.length; i++) {
+	// Frame frame = frames[i];
+	//
+	// if (frame instanceof JFrame) {
+	// JFrame jf = (JFrame) frame;
+	// if (jf.getRootPane() != null) {
+	// JMenuBar menuBar = jf.getJMenuBar();
+	// if (menuBar != null)
+	// SwingUtilities.updateComponentTreeUI(menuBar);
+	// }
+	// }
+	// // fix for defect 134 - menubars on internal frames
+	// MenuSearchWidget.showSearchPanels(frame);
+	// }
+	// };
+	// });
+	// }
 
 	/*
 	 * (non-Javadoc)
@@ -633,10 +623,10 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 	public void installUI() {
 		final LafWidgetSupport lafSupport = LafWidgetRepository.getRepository()
 				.getLafSupport();
-		this.searchPanel = new SearchPanel(this.jmb);
-		this.jmb.add(searchPanel, this.jmb.getComponentCount());
-		this.searchPanel.setVisible(lafSupport.toInstallMenuSearch(this.jmb));
-		// NewMenuSearchWidget.panels.put(this.jmb, searchPanel);
+		this.searchPanel = new SearchPanel(this.jcomp);
+		this.jcomp.add(searchPanel, this.jcomp.getComponentCount());
+		this.searchPanel.setVisible(lafSupport.toInstallMenuSearch(this.jcomp));
+		// NewMenuSearchWidget.panels.put(this.jcomp, searchPanel);
 		// toAddListener = true;
 		// }
 
@@ -644,7 +634,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 		// need to add a container listener that will move a newly added
 		// JMenu one entry before the last (so that our search panel
 		// will always be the last).
-		this.jmb.addContainerListener(new ContainerAdapter() {
+		this.jcomp.addContainerListener(new ContainerAdapter() {
 			@Override
 			public void componentAdded(ContainerEvent e) {
 				if (!(e.getChild() instanceof JMenu))
@@ -652,20 +642,22 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 				if (!inEvent) {
 					inEvent = true;
 					Component removed = null;
-					for (int i = 0; i < MenuSearchWidget.this.jmb
+					for (int i = 0; i < MenuSearchWidget.this.jcomp
 							.getComponentCount(); i++) {
-						if (MenuSearchWidget.this.jmb.getComponent(i) instanceof SearchPanel) {
-							removed = MenuSearchWidget.this.jmb.getComponent(i);
+						if (MenuSearchWidget.this.jcomp.getComponent(i) instanceof SearchPanel) {
+							removed = MenuSearchWidget.this.jcomp
+									.getComponent(i);
 							break;
 						}
 					}
 					if (removed != null) {
-						MenuSearchWidget.this.jmb.remove(removed);
-						MenuSearchWidget.this.jmb.add(removed,
-								MenuSearchWidget.this.jmb.getComponentCount());
+						MenuSearchWidget.this.jcomp.remove(removed);
+						MenuSearchWidget.this.jcomp
+								.add(removed, MenuSearchWidget.this.jcomp
+										.getComponentCount());
 						// Show search panel only if the LAF-specific
 						// support requests this
-						if (lafSupport.toInstallMenuSearch(jmb))
+						if (lafSupport.toInstallMenuSearch(jcomp))
 							removed.setVisible(true);
 						else
 							removed.setVisible(false);
@@ -677,9 +669,9 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 		// }
 
 		// SearchPanel sp = (SearchPanel)
-		// NewMenuSearchWidget.panels.get(this.jmb);
+		// NewMenuSearchWidget.panels.get(this.jcomp);
 		// if (sp != null) {
-		searchPanel.applyComponentOrientation(this.jmb
+		searchPanel.applyComponentOrientation(this.jcomp
 				.getComponentOrientation());
 		// }
 	}
@@ -691,7 +683,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 	 */
 	@Override
 	public void uninstallUI() {
-		this.jmb.remove(this.searchPanel);
+		this.jcomp.remove(this.searchPanel);
 		super.uninstallUI();
 	}
 
@@ -709,7 +701,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 				if ("componentOrientation".equals(evt.getPropertyName())) {
 					// final SearchPanel sp = (SearchPanel)
 					// NewMenuSearchWidget.panels
-					// .get(NewMenuSearchWidget.this.jmb);
+					// .get(NewMenuSearchWidget.this.jcomp);
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
 							if (searchPanel != null) {
@@ -730,7 +722,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 				}
 			}
 		};
-		this.jmb.addPropertyChangeListener(this.propertyListener);
+		this.jcomp.addPropertyChangeListener(this.propertyListener);
 	}
 
 	/*
@@ -740,7 +732,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.jmb.removePropertyChangeListener(this.propertyListener);
+		this.jcomp.removePropertyChangeListener(this.propertyListener);
 		this.propertyListener = null;
 	}
 
@@ -748,7 +740,7 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 		LafWidgetSupport support = LafWidgetRepository.getRepository()
 				.getLafSupport();
 		// SearchPanel searchPanel = (SearchPanel) NewMenuSearchWidget.panels
-		// .get(this.jmb);
+		// .get(this.jcomp);
 		if (searchPanel == null)
 			return;
 		for (Map.Entry<Integer, JButton> entry : searchPanel.resultButtons
@@ -767,7 +759,8 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 				: support.getSearchIcon(iconDim, searchPanel
 						.getComponentOrientation());
 		searchPanel.searchButton.setIcon(searchIcon);
-		ResourceBundle bundle = LafWidgetUtilities.getResourceBundle(this.jmb);
+		ResourceBundle bundle = LafWidgetUtilities
+				.getResourceBundle(this.jcomp);
 		searchPanel.searchButton.setToolTipText(bundle
 				.getString("Tooltip.menuSearchButton"));
 		searchPanel.searchStringField.setToolTipText(bundle
@@ -855,7 +848,8 @@ public class MenuSearchWidget extends LafWidgetAdapter implements Resettable {
 			if (!this.searchPanel.searchButton.isVisible())
 				return;
 
-			boolean leftToRight = jmb.getComponentOrientation().isLeftToRight();
+			boolean leftToRight = jcomp.getComponentOrientation()
+					.isLeftToRight();
 
 			if (leftToRight) {
 				// start from the toggle button
