@@ -229,9 +229,9 @@ public class ScrollPaneSelector extends JComponent {
 				// public void fadePerformed(FadeKind fadeKind,
 				// float fadeCycle10) {
 				// int newWidth = (int) (startDim.width
-				// * fadeCycle10 / 10.0);
+				// * fadeCycle);
 				// int newHeight = (int) (startDim.height
-				// * fadeCycle10 / 10.0);
+				// * fadeCycle);
 				// int newX = startCorner.x;//centerX - newWidth / 2;
 				// int newY = startCorner.y;//centerY - newHeight / 2;
 				// // thePopupMenu.setBounds(newX, newY, newWidth,
@@ -345,10 +345,10 @@ public class ScrollPaneSelector extends JComponent {
 		Graphics2D g = (Graphics2D) g1D.create();
 
 		if (FadeTracker.getInstance().isTracked(thePopupMenu, SCROLL_HIDE_KIND)) {
-			float fade10 = FadeTracker.getInstance().getFade10(thePopupMenu,
+			float fade = FadeTracker.getInstance().getFade(thePopupMenu,
 					SCROLL_HIDE_KIND);
 			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,
-					fade10 / 10.0f));
+					fade));
 		}
 
 		Insets insets = getInsets();
@@ -538,7 +538,7 @@ public class ScrollPaneSelector extends JComponent {
 		if (toAnimate) {
 			FadeTracker.getInstance().trackFadeIn(
 					ScrollPaneSelector.SCROLL_FADE_KIND, theComponent, false,
-					new EDTFadeTrackerAdapter() {
+					new UIThreadFadeTrackerAdapter() {
 						@Override
 						public void fadeEnded(FadeKind fadeKind) {
 							theComponent.scrollRectToVisible(newRectangle);
@@ -547,11 +547,9 @@ public class ScrollPaneSelector extends JComponent {
 
 						@Override
 						public void fadePerformed(FadeKind fadeKind,
-								float fadeCycle10) {
-							int x = (int) (oldRectangle.x + fadeCycle10
-									* aDeltaX / 10.0);
-							int y = (int) (oldRectangle.y + fadeCycle10
-									* aDeltaY / 10.0);
+								float fadeCycle) {
+							int x = (int) (oldRectangle.x + fadeCycle * aDeltaX);
+							int y = (int) (oldRectangle.y + fadeCycle * aDeltaY);
 							theComponent
 									.scrollRectToVisible(new Rectangle(x, y,
 											oldRectangle.width,
