@@ -34,7 +34,6 @@ import java.awt.event.HierarchyListener;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
-import javax.swing.JComponent;
 import javax.swing.JScrollPane;
 import javax.swing.plaf.basic.ComboPopup;
 
@@ -46,12 +45,7 @@ import org.jvnet.lafwidget.preview.PreviewPainter;
  * 
  * @author Kirill Grouchnikov
  */
-public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
-	/**
-	 * The associated scroll pane.
-	 */
-	protected JScrollPane scrollPane;
-
+public class ScrollPaneSelectorWidget extends LafWidgetAdapter<JScrollPane> {
 	/**
 	 * The scroll pane selector for the associated scroll pane.
 	 */
@@ -69,12 +63,6 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 	 */
 	protected PropertyChangeListener propertyChangeListener;
 
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.scrollPane = (JScrollPane) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -92,14 +80,14 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 	@Override
 	public void installUI() {
 		if (LafWidgetRepository.getRepository().getLafSupport()
-				.toInstallExtraElements(this.scrollPane)) {
+				.toInstallExtraElements(this.jcomp)) {
 
 			PreviewPainter pPainter = LafWidgetUtilities2
-					.getComponentPreviewPainter(this.scrollPane);
+					.getComponentPreviewPainter(this.jcomp);
 			if (pPainter == null)
 				return;
 			this.scrollPaneSelector = new ScrollPaneSelector();
-			this.scrollPaneSelector.installOnScrollPane(this.scrollPane);
+			this.scrollPaneSelector.installOnScrollPane(this.jcomp);
 		}
 	}
 
@@ -125,7 +113,7 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 			 * @see java.awt.event.HierarchyListener#hierarchyChanged(java.awt.event.HierarchyEvent)
 			 */
 			public void hierarchyChanged(HierarchyEvent e) {
-				if (scrollPane.getParent() instanceof ComboPopup) {
+				if (jcomp.getParent() instanceof ComboPopup) {
 					if (scrollPaneSelector != null) {
 						scrollPaneSelector.uninstallFromScrollPane();
 						scrollPaneSelector = null;
@@ -133,14 +121,14 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 				}
 			}
 		};
-		this.scrollPane.addHierarchyListener(this.hierarchyListener);
+		this.jcomp.addHierarchyListener(this.hierarchyListener);
 
 		this.propertyChangeListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
 				if (LafWidget.COMPONENT_PREVIEW_PAINTER.equals(evt
 						.getPropertyName())) {
 					PreviewPainter pPainter = LafWidgetUtilities2
-							.getComponentPreviewPainter(scrollPane);
+							.getComponentPreviewPainter(jcomp);
 					// Uninstall old scroll pane selector
 					if (scrollPaneSelector != null) {
 						scrollPaneSelector.uninstallFromScrollPane();
@@ -149,12 +137,12 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 					// Install new scroll pane selector
 					if (pPainter != null) {
 						scrollPaneSelector = new ScrollPaneSelector();
-						scrollPaneSelector.installOnScrollPane(scrollPane);
+						scrollPaneSelector.installOnScrollPane(jcomp);
 					}
 				}
 			}
 		};
-		this.scrollPane.addPropertyChangeListener(this.propertyChangeListener);
+		this.jcomp.addPropertyChangeListener(this.propertyChangeListener);
 	}
 
 	/*
@@ -164,11 +152,10 @@ public class ScrollPaneSelectorWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.scrollPane.removeHierarchyListener(this.hierarchyListener);
+		this.jcomp.removeHierarchyListener(this.hierarchyListener);
 		this.hierarchyListener = null;
 
-		this.scrollPane
-				.removePropertyChangeListener(this.propertyChangeListener);
+		this.jcomp.removePropertyChangeListener(this.propertyChangeListener);
 		this.propertyChangeListener = null;
 	}
 }
