@@ -31,7 +31,6 @@ package org.jvnet.lafwidget.tabbed;
 
 import java.awt.event.*;
 
-import javax.swing.JComponent;
 import javax.swing.JTabbedPane;
 
 import org.jvnet.lafwidget.*;
@@ -41,12 +40,7 @@ import org.jvnet.lafwidget.*;
  * 
  * @author Kirill Grouchnikov
  */
-public class TabHoverPreviewWidget extends LafWidgetAdapter {
-	/**
-	 * The associated tabbed pane.
-	 */
-	protected JTabbedPane jtp;
-
+public class TabHoverPreviewWidget extends LafWidgetAdapter<JTabbedPane> {
 	/**
 	 * Mouse listener for rollover effects.
 	 */
@@ -111,7 +105,7 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.MouseMotionListener#mouseMoved(java.awt.event.MouseEvent)
 		 */
 		public void mouseMoved(MouseEvent e) {
-			if (e.getSource() != TabHoverPreviewWidget.this.jtp)
+			if (e.getSource() != jcomp)
 				return;
 
 			LafWidgetSupport lafSupport = LafWidgetRepository.getRepository()
@@ -120,43 +114,35 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 			int currRolledOver = 0;
 
 			try {
-				currRolledOver = lafSupport
-						.getRolloverTabIndex(TabHoverPreviewWidget.this.jtp);
+				currRolledOver = lafSupport.getRolloverTabIndex(jcomp);
 			} catch (UnsupportedOperationException uoe) {
 				// Some problems in LAF support - may happen during the LAF
 				// switch when this event is processed after a LAF that doesn't
 				// have the laf-widget support is set. Just ignore it.
 				return;
 			}
-			if (currRolledOver >= TabHoverPreviewWidget.this.jtp.getTabCount())
+			if (currRolledOver >= jcomp.getTabCount())
 				return;
 
-			if (currRolledOver != TabHoverPreviewWidget.this.jtp
-					.getSelectedIndex()) {
+			if (currRolledOver != jcomp.getSelectedIndex()) {
 				if (currRolledOver == this.prevRolledOver) {
 					if ((currRolledOver >= 0)
-							&& (currRolledOver < TabHoverPreviewWidget.this.jtp
-									.getTabCount())
-							&& TabHoverPreviewWidget.this.jtp
-									.isEnabledAt(currRolledOver)) {
+							&& (currRolledOver < jcomp.getTabCount())
+							&& jcomp.isEnabledAt(currRolledOver)) {
 						TabPreviewWindow.getInstance().postPreviewRequest(
-								TabHoverPreviewWidget.this.jtp, currRolledOver);
+								jcomp, currRolledOver);
 					}
 				} else {
 					if ((this.prevRolledOver >= 0)
-							&& (this.prevRolledOver < TabHoverPreviewWidget.this.jtp
-									.getTabCount())
-							&& TabHoverPreviewWidget.this.jtp
-									.isEnabledAt(this.prevRolledOver)) {
+							&& (this.prevRolledOver < jcomp.getTabCount())
+							&& jcomp.isEnabledAt(this.prevRolledOver)) {
 						TabPreviewWindow.cancelPreviewRequest();
 					}
 					if ((currRolledOver >= 0)
-							&& (currRolledOver < TabHoverPreviewWidget.this.jtp
-									.getTabCount())
-							&& TabHoverPreviewWidget.this.jtp
-									.isEnabledAt(currRolledOver)) {
+							&& (currRolledOver < jcomp.getTabCount())
+							&& jcomp.isEnabledAt(currRolledOver)) {
 						TabPreviewWindow.getInstance().postPreviewRequest(
-								TabHoverPreviewWidget.this.jtp, currRolledOver);
+								jcomp, currRolledOver);
 					}
 				}
 			} else {
@@ -173,27 +159,14 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 		 */
 		public void mouseExited(MouseEvent e) {
 			if ((this.prevRolledOver >= 0)
-					&& (this.prevRolledOver < TabHoverPreviewWidget.this.jtp
-							.getTabCount())
-					&& TabHoverPreviewWidget.this.jtp
-							.isEnabledAt(this.prevRolledOver)) {
+					&& (this.prevRolledOver < jcomp.getTabCount())
+					&& jcomp.isEnabledAt(this.prevRolledOver)) {
 				TabPreviewWindow.cancelPreviewRequest();
 			}
 			this.prevRolledOver = -1;
 		}
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.jtp = (JTabbedPane) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -202,8 +175,8 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 	@Override
 	public void installListeners() {
 		this.baseRolloverHandler = new MouseRolloverHandler();
-		this.jtp.addMouseMotionListener(this.baseRolloverHandler);
-		this.jtp.addMouseListener(this.baseRolloverHandler);
+		this.jcomp.addMouseMotionListener(this.baseRolloverHandler);
+		this.jcomp.addMouseListener(this.baseRolloverHandler);
 	}
 
 	/*
@@ -214,8 +187,8 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 	@Override
 	public void uninstallListeners() {
 		if (this.baseRolloverHandler != null) {
-			this.jtp.removeMouseMotionListener(this.baseRolloverHandler);
-			this.jtp.removeMouseListener(this.baseRolloverHandler);
+			this.jcomp.removeMouseMotionListener(this.baseRolloverHandler);
+			this.jcomp.removeMouseListener(this.baseRolloverHandler);
 			this.baseRolloverHandler = null;
 		}
 	}
@@ -228,7 +201,7 @@ public class TabHoverPreviewWidget extends LafWidgetAdapter {
 	@Override
 	public void uninstallUI() {
 		if (TabPreviewThread.instanceRunning()) {
-			TabPreviewThread.getInstance().cancelTabPreviewRequests(this.jtp);
+			TabPreviewThread.getInstance().cancelTabPreviewRequests(this.jcomp);
 		}
 		TabPreviewWindow.cancelPreviewRequest();
 
