@@ -914,7 +914,7 @@ public class TabOverviewDialog extends JDialog {
 						FadeTracker.getInstance().trackFadeIn(
 								FadeKind.ROLLOVER,
 								overviewPanel.previewControls[index], false,
-								new EDTFadeTrackerAdapter() {
+								new UIThreadFadeTrackerAdapter() {
 									@Override
 									public void fadePerformed(
 											FadeKind fadeKind, float fadeCycle10) {
@@ -945,7 +945,7 @@ public class TabOverviewDialog extends JDialog {
 						FadeTracker.getInstance().trackFadeOut(
 								FadeKind.ROLLOVER,
 								overviewPanel.previewControls[index], false,
-								new EDTFadeTrackerAdapter() {
+								new UIThreadFadeTrackerAdapter() {
 									@Override
 									public void fadePerformed(
 											FadeKind fadeKind, float fadeCycle10) {
@@ -1004,8 +1004,8 @@ public class TabOverviewDialog extends JDialog {
 					- this.getLocationOnScreen().y;
 			double factor = (index == currHoverIndex) ? 1.2 : 1.0;
 			if (FadeTracker.getInstance().isTracked(child, FadeKind.ROLLOVER)) {
-				factor = 1.0 + 0.2 * FadeTracker.getInstance().getFade10(child,
-						FadeKind.ROLLOVER) / 10.0;
+				factor = 1.0 + 0.2 * FadeTracker.getInstance().getFade(child,
+						FadeKind.ROLLOVER);
 			}
 			int bw = (int) (cBounds.width * factor);
 			int bh = (int) (cBounds.height * factor);
