@@ -42,33 +42,17 @@ import org.jvnet.lafwidget.*;
  * 
  * @author Kirill Grouchnikov
  */
-public class TabOverviewDialogWidget extends LafWidgetAdapter {
+public class TabOverviewDialogWidget extends LafWidgetAdapter<JTabbedPane> {
 	/**
 	 * Tab overview button.
 	 */
 	protected TabOverviewButton overviewButton;
 
-	/**
-	 * The associated tabbed pane.
-	 */
-	protected JTabbedPane jtp;
-
 	/**
 	 * Listens on changes to relevant tabbed pane properties.
 	 */
 	protected PropertyChangeListener propertyListener;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.jtp = (JTabbedPane) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -76,7 +60,7 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void installComponents() {
-		this.overviewButton = new TabOverviewButton(this.jtp);
+		this.overviewButton = new TabOverviewButton(this.jcomp);
 	}
 
 	/*
@@ -87,14 +71,14 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 	@Override
 	public void installDefaults() {
 		TabPreviewPainter previewPainter = LafWidgetUtilities2
-				.getTabPreviewPainter(this.jtp);
+				.getTabPreviewPainter(this.jcomp);
 		if ((previewPainter != null)
-				&& previewPainter.hasOverviewDialog(this.jtp)) {
+				&& previewPainter.hasOverviewDialog(this.jcomp)) {
 
 			LafWidgetSupport lafSupport = LafWidgetRepository.getRepository()
 					.getLafSupport();
 
-			Insets currTabAreaInsets = lafSupport.getTabAreaInsets(this.jtp);
+			Insets currTabAreaInsets = lafSupport.getTabAreaInsets(this.jcomp);
 			if (currTabAreaInsets == null)
 				currTabAreaInsets = UIManager
 						.getInsets("TabbedPane.tabAreaInsets");
@@ -104,12 +88,12 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 							.getLookupButtonSize()
 							+ 2 + currTabAreaInsets.left,
 					currTabAreaInsets.bottom, currTabAreaInsets.right);
-			lafSupport.setTabAreaInsets(this.jtp, tabAreaInsets);
+			lafSupport.setTabAreaInsets(this.jcomp, tabAreaInsets);
 
-			this.jtp.add(this.overviewButton);
+			this.jcomp.add(this.overviewButton);
 			this.overviewButton.setVisible(true);
-			this.jtp.setComponentZOrder(this.overviewButton, 0);
-			this.overviewButton.updateLocation(this.jtp, tabAreaInsets);
+			this.jcomp.setComponentZOrder(this.overviewButton, 0);
+			this.overviewButton.updateLocation(this.jcomp, tabAreaInsets);
 		}
 	}
 
@@ -120,8 +104,8 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallComponents() {
-		if (this.overviewButton.getParent() == this.jtp)
-			this.jtp.remove(this.overviewButton);
+		if (this.overviewButton.getParent() == this.jcomp)
+			this.jcomp.remove(this.overviewButton);
 	}
 
 	/*
@@ -137,7 +121,7 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 						.getRepository().getLafSupport();
 
 				Insets lafInsets = lafSupport
-						.getTabAreaInsets(TabOverviewDialogWidget.this.jtp);
+						.getTabAreaInsets(TabOverviewDialogWidget.this.jcomp);
 				final Insets currTabAreaInsets = (lafInsets == null) ? UIManager
 						.getInsets("TabbedPane.tabAreaInsets")
 						: lafInsets;
@@ -145,11 +129,11 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 				if (LafWidget.TABBED_PANE_PREVIEW_PAINTER.equals(evt
 						.getPropertyName())) {
 					TabPreviewPainter previewPainter = LafWidgetUtilities2
-							.getTabPreviewPainter(TabOverviewDialogWidget.this.jtp);
+							.getTabPreviewPainter(TabOverviewDialogWidget.this.jcomp);
 
 					if ((previewPainter != null)
 							&& previewPainter
-									.hasOverviewDialog(TabOverviewDialogWidget.this.jtp)) {
+									.hasOverviewDialog(TabOverviewDialogWidget.this.jcomp)) {
 						Insets tabAreaInsets = new Insets(
 								currTabAreaInsets.top, LafWidgetRepository
 										.getRepository().getLafSupport()
@@ -157,21 +141,20 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 										+ 2 + currTabAreaInsets.left,
 								currTabAreaInsets.bottom,
 								currTabAreaInsets.right);
-						lafSupport
-								.setTabAreaInsets(
-										TabOverviewDialogWidget.this.jtp,
-										tabAreaInsets);
-						TabOverviewDialogWidget.this.jtp
+						lafSupport.setTabAreaInsets(
+								TabOverviewDialogWidget.this.jcomp,
+								tabAreaInsets);
+						TabOverviewDialogWidget.this.jcomp
 								.add(TabOverviewDialogWidget.this.overviewButton);
 						TabOverviewDialogWidget.this.overviewButton
 								.setVisible(true);
 						// jtp.setComponentZOrder(overviewButton, 0);
 						TabOverviewDialogWidget.this.overviewButton
 								.updateLocation(
-										TabOverviewDialogWidget.this.jtp,
+										TabOverviewDialogWidget.this.jcomp,
 										tabAreaInsets);
 					} else {
-						TabOverviewDialogWidget.this.jtp
+						TabOverviewDialogWidget.this.jcomp
 								.remove(TabOverviewDialogWidget.this.overviewButton);
 					}
 				}
@@ -179,10 +162,10 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
 							if (TabOverviewDialogWidget.this.overviewButton
-									.getParent() == TabOverviewDialogWidget.this.jtp)
+									.getParent() == TabOverviewDialogWidget.this.jcomp)
 								TabOverviewDialogWidget.this.overviewButton
 										.updateLocation(
-												TabOverviewDialogWidget.this.jtp,
+												TabOverviewDialogWidget.this.jcomp,
 												currTabAreaInsets);
 						}
 					});
@@ -191,17 +174,17 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
 							if (TabOverviewDialogWidget.this.overviewButton
-									.getParent() == TabOverviewDialogWidget.this.jtp)
+									.getParent() == TabOverviewDialogWidget.this.jcomp)
 								TabOverviewDialogWidget.this.overviewButton
 										.updateLocation(
-												TabOverviewDialogWidget.this.jtp,
+												TabOverviewDialogWidget.this.jcomp,
 												currTabAreaInsets);
 						}
 					});
 				}
 			}
 		};
-		this.jtp.addPropertyChangeListener(this.propertyListener);
+		this.jcomp.addPropertyChangeListener(this.propertyListener);
 	}
 
 	/*
@@ -211,7 +194,7 @@ public class TabOverviewDialogWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.jtp.removePropertyChangeListener(this.propertyListener);
+		this.jcomp.removePropertyChangeListener(this.propertyListener);
 		this.propertyListener = null;
 	}
 
