@@ -469,31 +469,31 @@ public class TabPagerManager {
 		final Point prevWindowLocation = this.prevTabWindow.getLocation();
 		final Dimension prevWindowSize = this.prevTabWindow.getSize();
 		FadeTracker.getInstance().trackFadeOut(HIDE_TAB_PAGER_FADE_KIND,
-				this.currTabbedPane, false, new EDTFadeTrackerAdapter() {
+				this.currTabbedPane, false, new UIThreadFadeTrackerAdapter() {
 					@Override
 					public void fadePerformed(FadeKind fadeKind,
-							float fadeCycle10) {
+							float fadeCycle) {
 						int cx = currWindowLocation.x + currWindowSize.width
 								/ 2;
 						int cy = currWindowLocation.y + currWindowSize.height
 								/ 2;
-						int nWidth = (int) (currWindowSize.width * fadeCycle10 / 10.0);
+						int nWidth = (int) (currWindowSize.width * fadeCycle);
 						int nHeight = (int) (currWindowSize.height
-								* fadeCycle10 / 10.0);
+								* fadeCycle);
 						currTabWindow.setBounds(cx - nWidth / 2, cy - nHeight
 								/ 2, nWidth, nHeight);
 
 						cx = prevWindowLocation.x + prevWindowSize.width / 2;
 						cy = prevWindowLocation.y + prevWindowSize.height / 2;
-						nWidth = (int) (prevWindowSize.width * fadeCycle10 / 10.0);
-						nHeight = (int) (prevWindowSize.height * fadeCycle10 / 10.0);
+						nWidth = (int) (prevWindowSize.width * fadeCycle);
+						nHeight = (int) (prevWindowSize.height * fadeCycle);
 						prevTabWindow.setBounds(cx - nWidth / 2, cy - nHeight
 								/ 2, nWidth, nHeight);
 
 						cx = nextWindowLocation.x + nextWindowSize.width / 2;
 						cy = nextWindowLocation.y + nextWindowSize.height / 2;
-						nWidth = (int) (nextWindowSize.width * fadeCycle10 / 10.0);
-						nHeight = (int) (nextWindowSize.height * fadeCycle10 / 10.0);
+						nWidth = (int) (nextWindowSize.width * fadeCycle);
+						nHeight = (int) (nextWindowSize.height * fadeCycle);
 						nextTabWindow.setBounds(cx - nWidth / 2, cy - nHeight
 								/ 2, nWidth, nHeight);
 
@@ -526,9 +526,9 @@ public class TabPagerManager {
 		// / 2;
 		// int cy = prevWindowLocation.y + prevWindowSize.height
 		// / 2;
-		// int nWidth = (int) (prevWindowSize.width * fadeCycle10 / 10.0);
+		// int nWidth = (int) (prevWindowSize.width * fadeCycle);
 		// int nHeight = (int) (prevWindowSize.height
-		// * fadeCycle10 / 10.0);
+		// * fadeCycle);
 		// prevTabWindow.setBounds(cx - nWidth / 2, cy - nHeight
 		// / 2, nWidth, nHeight);
 		// }
@@ -547,9 +547,9 @@ public class TabPagerManager {
 		// / 2;
 		// int cy = nextWindowLocation.y + nextWindowSize.height
 		// / 2;
-		// int nWidth = (int) (nextWindowSize.width * fadeCycle10 / 10.0);
+		// int nWidth = (int) (nextWindowSize.width * fadeCycle);
 		// int nHeight = (int) (nextWindowSize.height
-		// * fadeCycle10 / 10.0);
+		// * fadeCycle);
 		// nextTabWindow.setBounds(cx - nWidth / 2, cy - nHeight
 		// / 2, nWidth, nHeight);
 		// }
