@@ -41,12 +41,8 @@ import org.jvnet.lafwidget.*;
  * 
  * @author Kirill Grouchnikov
  */
-public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
-	/**
-	 * The associated tabbed pane.
-	 */
-	protected JTabbedPane jtp;
-
+public class TabPagerWidget extends LafWidgetAdapter<JTabbedPane> implements
+		Resettable {
 	/**
 	 * Mouse wheel listener for Ctrl paging (from version 2.1).
 	 */
@@ -57,17 +53,6 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 	 */
 	protected MouseListener mouseListener;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.jtp = (JTabbedPane) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -76,7 +61,7 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 	@Override
 	public void installUI() {
 		super.installUI();
-		InputMap currMap = SwingUtilities.getUIInputMap(this.jtp,
+		InputMap currMap = SwingUtilities.getUIInputMap(this.jcomp,
 				JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
 
 		InputMap newMap = new InputMap();
@@ -98,43 +83,44 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 		newMap.put(KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0),
 				"tabSwitcherHide");
 
-		this.jtp.getActionMap().put("tabSwitcherForward", new AbstractAction() {
-			public void actionPerformed(ActionEvent e) {
-				// fix for issue 323 in Substance - don't show pager on tabbed
-				// panes with no preview painter
-				TabPreviewPainter tpp = LafWidgetUtilities2
-						.getTabPreviewPainter(TabPagerWidget.this.jtp);
-				if (tpp == null)
-					return;
+		this.jcomp.getActionMap().put("tabSwitcherForward",
+				new AbstractAction() {
+					public void actionPerformed(ActionEvent e) {
+						// fix for issue 323 in Substance - don't show pager on tabbed
+						// panes with no preview painter
+						TabPreviewPainter tpp = LafWidgetUtilities2
+								.getTabPreviewPainter(TabPagerWidget.this.jcomp);
+						if (tpp == null)
+							return;
 
-				TabPagerManager te = TabPagerManager.getPager();
-				te.page(TabPagerWidget.this.jtp, true);
-			}
-		});
+						TabPagerManager te = TabPagerManager.getPager();
+						te.page(TabPagerWidget.this.jcomp, true);
+					}
+				});
 
-		this.jtp.getActionMap().put("tabSwitcherBackward",
+		this.jcomp.getActionMap().put("tabSwitcherBackward",
 				new AbstractAction() {
 					public void actionPerformed(ActionEvent e) {
 						// fix for issue 323 in Substance - don't show pager on
 						// tabbed panes with no preview painter
 						TabPreviewPainter tpp = LafWidgetUtilities2
-								.getTabPreviewPainter(TabPagerWidget.this.jtp);
+								.getTabPreviewPainter(TabPagerWidget.this.jcomp);
 						if (tpp == null)
 							return;
 
 						TabPagerManager te = TabPagerManager.getPager();
-						te.page(TabPagerWidget.this.jtp, false);
+						te.page(TabPagerWidget.this.jcomp, false);
 					}
 				});
 
-		this.jtp.getActionMap().put("tabSwitcherClose", new AbstractAction() {
+		this.jcomp.getActionMap().put("tabSwitcherClose", new AbstractAction() {
 			public void actionPerformed(ActionEvent e) {
 				SwingUtilities.invokeLater(new Runnable() {
 					public void run() {
 						// fix for issue 323 in Substance - don't show pager on
 						// tabbed panes with no preview painter
 						TabPreviewPainter tpp = LafWidgetUtilities2
-								.getTabPreviewPainter(TabPagerWidget.this.jtp);
+								.getTabPreviewPainter(TabPagerWidget.this.jcomp);
 						if (tpp == null)
 							return;
 
@@ -144,15 +130,15 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 						// of disabled tabs).
 						if ((index >= 0)
 								&& tpp.isSensitiveToEvents(
-										TabPagerWidget.this.jtp, index)) {
-							TabPagerWidget.this.jtp.setSelectedIndex(index);
+										TabPagerWidget.this.jcomp, index)) {
+							TabPagerWidget.this.jcomp.setSelectedIndex(index);
 						}
 					}
 				});
 			}
 		});
 
-		this.jtp.getActionMap().put("tabSwitcherHide", new AbstractAction() {
+		this.jcomp.getActionMap().put("tabSwitcherHide", new AbstractAction() {
 			public void actionPerformed(ActionEvent e) {
 				TabPagerManager te = TabPagerManager.getPager();
 				if (te.isVisible()) {
@@ -160,7 +146,7 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 				} else {
 					// fix for defect 233 on Substance - the ESCAPE event
 					// is not dispatched when tab pager is not showing.
-					Component comp = jtp.getParent();
+					Component comp = jcomp.getParent();
 					while (comp != null) {
 						if (comp instanceof JComponent) {
 							JComponent jc = (JComponent) comp;
@@ -179,7 +165,7 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 			}
 		});
 
-		SwingUtilities.replaceUIInputMap(this.jtp,
+		SwingUtilities.replaceUIInputMap(this.jcomp,
 				JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT, newMap);
 	}
 
@@ -200,8 +186,8 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 	 */
 	@Override
 	public void installListeners() {
-		this.mouseWheelListener = new TabPagerMouseWheelListener(this.jtp);
-		this.jtp.addMouseWheelListener(this.mouseWheelListener);
+		this.mouseWheelListener = new TabPagerMouseWheelListener(this.jcomp);
+		this.jcomp.addMouseWheelListener(this.mouseWheelListener);
 		this.mouseListener = new MouseAdapter() {
 			@Override
 			public void mouseClicked(MouseEvent e) {
@@ -211,13 +197,14 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 							TabPagerManager te = TabPagerManager.getPager();
 							int index = te.hide();
 							if (index >= 0)
-								TabPagerWidget.this.jtp.setSelectedIndex(index);
+								TabPagerWidget.this.jcomp
+										.setSelectedIndex(index);
 						}
 					});
 				}
 			}
 		};
-		this.jtp.addMouseListener(this.mouseListener);
+		this.jcomp.addMouseListener(this.mouseListener);
 	}
 
 	/*
@@ -227,10 +214,10 @@ public class TabPagerWidget extends LafWidgetAdapter implements Resettable {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.jtp.removeMouseWheelListener(this.mouseWheelListener);
+		this.jcomp.removeMouseWheelListener(this.mouseWheelListener);
 		this.mouseWheelListener = null;
 
-		this.jtp.removeMouseListener(this.mouseListener);
+		this.jcomp.removeMouseListener(this.mouseListener);
 		this.mouseListener = null;
 	}
 
