@@ -195,28 +195,34 @@ public class TabPreviewThread extends TrackableThread {
 					// nextPreviewInfo.toPreviewAllTabs;
 
 					if (nextPreviewInfo.toPreviewAllTabs) {
-						// The call to start() is only relevant for the
-						// preview of all tabs.
-						nextPreviewInfo.previewCallback.start(jtp, jtp
-								.getTabCount(), nextPreviewInfo);
+						SwingUtilities.invokeLater(new Runnable() {
+							@Override
+							public void run() {
+								// The call to start() is only relevant for the
+								// preview of all tabs.
+								nextPreviewInfo.previewCallback.start(jtp, jtp
+										.getTabCount(), nextPreviewInfo);
+							}
+						});
 
 						for (int i = 0; i < tabCount; i++) {
 							final int index = i;
-							// SwingUtilities.invokeLater(new Runnable() {
-							// public void run() {
-							getSingleTabPreviewImage(jtp, previewPainter,
-									nextPreviewInfo, index);
-							// }
-							// });
+							SwingUtilities.invokeLater(new Runnable() {
+								public void run() {
+									getSingleTabPreviewImage(jtp,
+											previewPainter, nextPreviewInfo,
+											index);
+								}
+							});
 						}
 					} else {
-						// SwingUtilities.invokeLater(new Runnable() {
-						// public void run() {
-						getSingleTabPreviewImage(jtp, previewPainter,
-								nextPreviewInfo,
-								nextPreviewInfo.tabIndexToPreview);
-						// }
-						// });
+						SwingUtilities.invokeLater(new Runnable() {
+							public void run() {
+								getSingleTabPreviewImage(jtp, previewPainter,
+										nextPreviewInfo,
+										nextPreviewInfo.tabIndexToPreview);
+							}
+						});
 					}
 					// }
 					// });
