@@ -137,9 +137,10 @@ public class TabPreviewWindow extends JWindow implements ActionListener {
 			/*
 			 * (non-Javadoc)
 			 * 
-			 * @see org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewCallback#start(javax.swing.JTabbedPane,
-			 *      int,
-			 *      org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewInfo)
+			 * @see
+			 * org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewCallback
+			 * #start(javax.swing.JTabbedPane, int,
+			 * org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewInfo)
 			 */
 			public void start(JTabbedPane tabPane, int tabCount,
 					TabPreviewInfo tabPreviewInfo) {
@@ -150,8 +151,10 @@ public class TabPreviewWindow extends JWindow implements ActionListener {
 			/*
 			 * (non-Javadoc)
 			 * 
-			 * @see org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewCallback#offer(javax.swing.JTabbedPane,
-			 *      int, java.awt.image.BufferedImage)
+			 * @see
+			 * org.jvnet.lafwidget.tabbed.TabPreviewThread.TabPreviewCallback
+			 * #offer(javax.swing.JTabbedPane, int,
+			 * java.awt.image.BufferedImage)
 			 */
 			public void offer(JTabbedPane tabPane, int tabIndex,
 					BufferedImage componentSnap) {
@@ -177,11 +180,10 @@ public class TabPreviewWindow extends JWindow implements ActionListener {
 						FadeTracker fadeTracker = FadeTracker.getInstance();
 						// Check if in the middle of fade-in
 						if (fadeTracker.isTracked(this, FadeKind.ENABLE)) {
-							float fadeFactor10 = fadeTracker.getFade10(this,
+							float fadeFactor = fadeTracker.getFade(this,
 									FadeKind.ENABLE);
-							g2.setComposite(AlphaComposite.getInstance(
-									AlphaComposite.SRC_OVER,
-									fadeFactor10 / 10.0f));
+							g2.setComposite(AlphaComposite.SrcOver
+									.derive(fadeFactor));
 						}
 						super.paintComponent(g2);
 						g2.dispose();
@@ -226,7 +228,8 @@ public class TabPreviewWindow extends JWindow implements ActionListener {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
+	 * @see
+	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 	 */
 	public void actionPerformed(ActionEvent e) {
 		if (currTabPreviewInfo == null)
