@@ -46,29 +46,12 @@ import org.jvnet.lafwidget.LafWidgetUtilities;
  * 
  * @author Kirill Grouchnikov
  */
-public class EditContextMenuWidget extends LafWidgetAdapter {
-	/**
-	 * The associated text component.
-	 */
-	protected JTextComponent textComp;
-
+public class EditContextMenuWidget extends LafWidgetAdapter<JTextComponent> {
 	/**
 	 * Mouse listener for showing the edit context menu.
 	 */
 	protected MouseListener menuMouseListener;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-
-		this.textComp = (JTextComponent) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -99,14 +82,13 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 			}
 
 			private void handleMouseEvent(MouseEvent e) {
-				if (!LafWidgetUtilities
-						.hasTextEditContextMenu(EditContextMenuWidget.this.textComp))
+				if (!LafWidgetUtilities.hasTextEditContextMenu(jcomp))
 					return;
 				if (!e.isPopupTrigger())
 					return;
 
 				// request focus
-				EditContextMenuWidget.this.textComp.requestFocus(true);
+				jcomp.requestFocus(true);
 
 				JPopupMenu editMenu = new JPopupMenu();
 				editMenu.add(new CutAction());
@@ -117,11 +99,11 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 				editMenu.add(new SelectAllAction());
 
 				Point pt = SwingUtilities.convertPoint(e.getComponent(), e
-						.getPoint(), EditContextMenuWidget.this.textComp);
-				editMenu.show(EditContextMenuWidget.this.textComp, pt.x, pt.y);
+						.getPoint(), jcomp);
+				editMenu.show(jcomp, pt.x, pt.y);
 			}
 		};
-		this.textComp.addMouseListener(this.menuMouseListener);
+		jcomp.addMouseListener(this.menuMouseListener);
 	}
 
 	/*
@@ -131,7 +113,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.textComp.removeMouseListener(this.menuMouseListener);
+		jcomp.removeMouseListener(this.menuMouseListener);
 		this.menuMouseListener = null;
 	}
 
@@ -145,7 +127,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * Creates new <code>Paste</code> action.
 		 */
 		public PasteAction() {
-			super(LafWidgetUtilities.getResourceBundle(textComp).getString(
+			super(LafWidgetUtilities.getResourceBundle(jcomp).getString(
 					"EditMenu.paste"), new ImageIcon(
 					EditContextMenuWidget.class.getClassLoader().getResource(
 							"org/jvnet/lafwidget/text/edit-paste.png")));
@@ -157,7 +139,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 		 */
 		public void actionPerformed(ActionEvent e) {
-			EditContextMenuWidget.this.textComp.paste();
+			jcomp.paste();
 		}
 
 		/*
@@ -167,8 +149,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 */
 		@Override
 		public boolean isEnabled() {
-			if (EditContextMenuWidget.this.textComp.isEditable()
-					&& EditContextMenuWidget.this.textComp.isEnabled()) {
+			if (jcomp.isEditable() && jcomp.isEnabled()) {
 				Transferable contents = Toolkit.getDefaultToolkit()
 						.getSystemClipboard().getContents(this);
 				return contents.isDataFlavorSupported(DataFlavor.stringFlavor);
@@ -187,7 +168,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * Creates new <code>Select All</code> action.
 		 */
 		public SelectAllAction() {
-			super(LafWidgetUtilities.getResourceBundle(textComp).getString(
+			super(LafWidgetUtilities.getResourceBundle(jcomp).getString(
 					"EditMenu.selectAll"), new ImageIcon(
 					EditContextMenuWidget.class.getClassLoader().getResource(
 							"org/jvnet/lafwidget/text/edit-select-all.png")));
@@ -199,7 +180,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 		 */
 		public void actionPerformed(ActionEvent e) {
-			EditContextMenuWidget.this.textComp.selectAll();
+			jcomp.selectAll();
 		}
 
 		/*
@@ -209,8 +190,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 */
 		@Override
 		public boolean isEnabled() {
-			return EditContextMenuWidget.this.textComp.isEnabled()
-					&& (EditContextMenuWidget.this.textComp.getText().length() > 0);
+			return jcomp.isEnabled() && (jcomp.getText().length() > 0);
 		}
 	}
 
@@ -224,7 +204,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * Creates new <code>Delete</code> action.
 		 */
 		public DeleteAction() {
-			super(LafWidgetUtilities.getResourceBundle(textComp).getString(
+			super(LafWidgetUtilities.getResourceBundle(jcomp).getString(
 					"EditMenu.delete"), new ImageIcon(
 					EditContextMenuWidget.class.getClassLoader().getResource(
 							"org/jvnet/lafwidget/text/edit-delete.png")));
@@ -236,7 +216,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 		 */
 		public void actionPerformed(ActionEvent e) {
-			EditContextMenuWidget.this.textComp.replaceSelection(null);
+			jcomp.replaceSelection(null);
 		}
 
 		/*
@@ -246,9 +226,8 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 */
 		@Override
 		public boolean isEnabled() {
-			return EditContextMenuWidget.this.textComp.isEditable()
-					&& EditContextMenuWidget.this.textComp.isEnabled()
-					&& (EditContextMenuWidget.this.textComp.getSelectedText() != null);
+			return jcomp.isEditable() && jcomp.isEnabled()
+					&& (jcomp.getSelectedText() != null);
 		}
 	}
 
@@ -262,7 +241,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * Creates new <code>Cut</code> action.
 		 */
 		public CutAction() {
-			super(LafWidgetUtilities.getResourceBundle(textComp).getString(
+			super(LafWidgetUtilities.getResourceBundle(jcomp).getString(
 					"EditMenu.cut"), new ImageIcon(EditContextMenuWidget.class
 					.getClassLoader().getResource(
 							"org/jvnet/lafwidget/text/edit-cut.png")));
@@ -274,7 +253,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 		 */
 		public void actionPerformed(ActionEvent e) {
-			EditContextMenuWidget.this.textComp.cut();
+			jcomp.cut();
 		}
 
 		/*
@@ -284,9 +263,8 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 */
 		@Override
 		public boolean isEnabled() {
-			return EditContextMenuWidget.this.textComp.isEditable()
-					&& EditContextMenuWidget.this.textComp.isEnabled()
-					&& (EditContextMenuWidget.this.textComp.getSelectedText() != null);
+			return jcomp.isEditable() && jcomp.isEnabled()
+					&& (jcomp.getSelectedText() != null);
 		}
 	}
 
@@ -300,7 +278,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * Creates new <code>Copy</code> action.
 		 */
 		public CopyAction() {
-			super(LafWidgetUtilities.getResourceBundle(textComp).getString(
+			super(LafWidgetUtilities.getResourceBundle(jcomp).getString(
 					"EditMenu.copy"), new ImageIcon(EditContextMenuWidget.class
 					.getClassLoader().getResource(
 							"org/jvnet/lafwidget/text/edit-copy.png")));
@@ -312,7 +290,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
 		 */
 		public void actionPerformed(ActionEvent e) {
-			EditContextMenuWidget.this.textComp.copy();
+			jcomp.copy();
 		}
 
 		/*
@@ -322,8 +300,7 @@ public class EditContextMenuWidget extends LafWidgetAdapter {
 		 */
 		@Override
 		public boolean isEnabled() {
-			return EditContextMenuWidget.this.textComp.isEnabled()
-					&& (EditContextMenuWidget.this.textComp.getSelectedText() != null);
+			return jcomp.isEnabled() && (jcomp.getSelectedText() != null);
 		}
 	}
 }
