@@ -33,7 +33,8 @@ import java.awt.*;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
-import javax.swing.*;
+import javax.swing.JPasswordField;
+import javax.swing.UIManager;
 import javax.swing.border.Border;
 import javax.swing.plaf.BorderUIResource;
 
@@ -45,12 +46,8 @@ import org.jvnet.lafwidget.utils.LafConstants.PasswordStrength;
  * 
  * @author Kirill Grouchnikov
  */
-public class PasswordStrengthCheckerWidget extends LafWidgetAdapter {
-	/**
-	 * The associated password field.
-	 */
-	protected JPasswordField passwordField;
-
+public class PasswordStrengthCheckerWidget extends
+		LafWidgetAdapter<JPasswordField> {
 	/**
 	 * Listens on changes to {@link LafWidget#PASSWORD_STRENGTH_CHECKER}
 	 * property.
@@ -127,18 +124,6 @@ public class PasswordStrengthCheckerWidget extends LafWidgetAdapter {
 		}
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-
-		this.passwordField = (JPasswordField) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -155,25 +140,21 @@ public class PasswordStrengthCheckerWidget extends LafWidgetAdapter {
 					if ((newValue != null)
 							&& (newValue instanceof PasswordStrengthChecker)
 							&& (!(oldValue instanceof PasswordStrengthChecker))) {
-						PasswordStrengthCheckerWidget.this.passwordField
+						jcomp
 								.setBorder(new BorderUIResource.CompoundBorderUIResource(
-										PasswordStrengthCheckerWidget.this.passwordField
-												.getBorder(),
+										jcomp.getBorder(),
 										new StrengthCheckedBorder()));
 					} else {
 						// restore core border
 						Border coreBorder = UIManager
 								.getBorder("PasswordField.border");
-						PasswordStrengthCheckerWidget.this.passwordField
-								.setBorder(coreBorder);
-						PasswordStrengthCheckerWidget.this.passwordField
-								.setToolTipText(null);
+						jcomp.setBorder(coreBorder);
+						jcomp.setToolTipText(null);
 					}
 				}
 			}
 		};
-		this.passwordField
-				.addPropertyChangeListener(this.strengthCheckerListener);
+		this.jcomp.addPropertyChangeListener(this.strengthCheckerListener);
 	}
 
 	/*
@@ -183,8 +164,7 @@ public class PasswordStrengthCheckerWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.passwordField
-				.removePropertyChangeListener(this.strengthCheckerListener);
+		this.jcomp.removePropertyChangeListener(this.strengthCheckerListener);
 		this.strengthCheckerListener = null;
 	}
 
@@ -198,13 +178,11 @@ public class PasswordStrengthCheckerWidget extends LafWidgetAdapter {
 		super.installDefaults();
 
 		// check if the property is already set - can happen on LAF change
-		Object checker = this.passwordField
+		Object checker = this.jcomp
 				.getClientProperty(LafWidget.PASSWORD_STRENGTH_CHECKER);
 		if ((checker != null) && (checker instanceof PasswordStrengthChecker)) {
-			this.passwordField
-					.setBorder(new BorderUIResource.CompoundBorderUIResource(
-							this.passwordField.getBorder(),
-							new StrengthCheckedBorder()));
+			this.jcomp.setBorder(new BorderUIResource.CompoundBorderUIResource(
+					this.jcomp.getBorder(), new StrengthCheckedBorder()));
 		}
 	}
 
