@@ -31,7 +31,6 @@ package org.jvnet.lafwidget.text;
 
 import java.awt.event.*;
 
-import javax.swing.JComponent;
 import javax.swing.SwingUtilities;
 import javax.swing.text.JTextComponent;
 
@@ -43,29 +42,13 @@ import org.jvnet.lafwidget.LafWidgetUtilities;
  * 
  * @author Kirill Grouchnikov
  */
-public class SelectAllOnFocusGainWidget extends LafWidgetAdapter {
-	/**
-	 * The associated text component.
-	 */
-	protected JTextComponent textComp;
-
+public class SelectAllOnFocusGainWidget extends
+		LafWidgetAdapter<JTextComponent> {
 	/**
 	 * The focus listener.
 	 */
 	protected FocusListener focusListener;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	@Override
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-
-		this.textComp = (JTextComponent) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -88,13 +71,14 @@ public class SelectAllOnFocusGainWidget extends LafWidgetAdapter {
 				SwingUtilities.invokeLater(new Runnable() {
 					public void run() {
 						if (LafWidgetUtilities
-								.hasTextFocusSelectAllProperty(textComp))
-							textComp.selectAll();
+								.hasTextFocusSelectAllProperty(jcomp)
+								&& jcomp.isEditable())
+							jcomp.selectAll();
 					}
 				});
 			}
 		};
-		this.textComp.addFocusListener(this.focusListener);
+		this.jcomp.addFocusListener(this.focusListener);
 	}
 
 	/*
@@ -104,7 +88,7 @@ public class SelectAllOnFocusGainWidget extends LafWidgetAdapter {
 	 */
 	@Override
 	public void uninstallListeners() {
-		this.textComp.removeFocusListener(this.focusListener);
+		this.jcomp.removeFocusListener(this.focusListener);
 		this.focusListener = null;
 	}
 }
