@@ -31,7 +31,6 @@ package org.jvnet.lafwidget.text;
 
 import java.awt.event.*;
 
-import javax.swing.JComponent;
 import javax.swing.SwingUtilities;
 import javax.swing.text.JTextComponent;
 
@@ -44,28 +43,12 @@ import org.jvnet.lafwidget.LafWidgetUtilities;
  * @author Kirill Grouchnikov
  * @since 2.1
  */
-public class SelectOnEscapeWidget extends LafWidgetAdapter {
-	/**
-	 * The associated text component.
-	 */
-	protected JTextComponent textComp;
-
+public class SelectOnEscapeWidget extends LafWidgetAdapter<JTextComponent> {
 	/**
 	 * The Escape key listener.
 	 */
 	protected KeyListener keyListener;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-
-		this.textComp = (JTextComponent) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -80,34 +63,35 @@ public class SelectOnEscapeWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#installListeners()
 	 */
+	@Override
 	public void installListeners() {
 		this.keyListener = new KeyAdapter() {
+			@Override
 			public void keyTyped(final KeyEvent e) {
-				if (LafWidgetUtilities
-						.hasTextFlipSelectOnEscapeProperty(textComp)
+				if (LafWidgetUtilities.hasTextFlipSelectOnEscapeProperty(jcomp)
 						&& (e.getKeyChar() == KeyEvent.VK_ESCAPE)) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							int selectionLength = textComp.getSelectionEnd()
-									- textComp.getSelectionStart();
+							int selectionLength = jcomp.getSelectionEnd()
+									- jcomp.getSelectionStart();
 							if (selectionLength == 0) {
-								textComp.selectAll();
+								jcomp.selectAll();
 							} else {
-								int lastPos = textComp.getSelectionEnd();
-								textComp.setSelectionStart(0);
-								textComp.setSelectionEnd(0);
-								textComp.setCaretPosition(lastPos);
+								int lastPos = jcomp.getSelectionEnd();
+								jcomp.setSelectionStart(0);
+								jcomp.setSelectionEnd(0);
+								jcomp.setCaretPosition(lastPos);
 							}
 							// dispatch to parent - especially useful
 							// for text components in dialogs that should
 							// be closed on pressing ESC.
-							textComp.getParent().dispatchEvent(e);
+							jcomp.getParent().dispatchEvent(e);
 						}
 					});
 				}
 			}
 		};
-		this.textComp.addKeyListener(this.keyListener);
+		this.jcomp.addKeyListener(this.keyListener);
 	}
 
 	/*
@@ -115,8 +99,9 @@ public class SelectOnEscapeWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#uninstallListeners()
 	 */
+	@Override
 	public void uninstallListeners() {
 		this.keyListener = null;
-		this.textComp.removeKeyListener(this.keyListener);
+		this.jcomp.removeKeyListener(this.keyListener);
 	}
 }
