@@ -39,7 +39,6 @@ import java.lang.reflect.Method;
 import java.util.Enumeration;
 import java.util.EventListener;
 
-import javax.swing.JComponent;
 import javax.swing.JTree;
 import javax.swing.event.EventListenerList;
 import javax.swing.tree.*;
@@ -50,9 +49,9 @@ import org.jvnet.lafwidget.*;
  * TreeWrapper is used to handle drag and drop and popup menus in any JTree.
  * 
  * @author Antonio Vieiro (antonio@antonioshome.net), $Author: kirillcool $
- * @version $Revision: 1.15 $
+ * @version $Revision: 1.16 $
  */
-public class TreeDragAndDropWidget extends LafWidgetAdapter {
+public class TreeDragAndDropWidget extends LafWidgetAdapter<JTree> {
 	/**
 	 * This to avoid excesive creation of objects in invocation.
 	 */
@@ -68,8 +67,6 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 	 */
 	private static Object[] EMPTY_OBJECT_ARRAY = new Object[0];
 
-	protected JTree tree;
-
 	protected DnDCellRendererProxy rendererProxy;
 
 	protected DragSource dragSource;
@@ -99,21 +96,12 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 		return false;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.lafwidget.LafWidgetAdapter#setComponent(javax.swing.JComponent)
-	 */
-	public void setComponent(JComponent jcomp) {
-		super.setComponent(jcomp);
-		this.tree = (JTree) jcomp;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#installListeners()
 	 */
+	@Override
 	public void installListeners() {
 		this.listeners = new EventListenerList();
 
@@ -131,7 +119,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 						hasDnd = ((Boolean) newValue).booleanValue();
 
 					if (!hadDnd && hasDnd
-							&& TreeDragAndDropWidget.this.tree.isEnabled()) {
+							&& TreeDragAndDropWidget.this.jcomp.isEnabled()) {
 						TreeDragAndDropWidget.this.installDnDSupport();
 					}
 					if (hadDnd && !hasDnd) {
@@ -146,7 +134,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 							.booleanValue();
 					if (!wasEnabled && isEnabled) {
 						if (LafWidgetUtilities
-								.hasAutomaticDnDSupport(TreeDragAndDropWidget.this.tree))
+								.hasAutomaticDnDSupport(TreeDragAndDropWidget.this.jcomp))
 							TreeDragAndDropWidget.this.installDnDSupport();
 					}
 					if (wasEnabled && !isEnabled)
@@ -154,10 +142,10 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 				}
 			}
 		};
-		this.tree.addPropertyChangeListener(this.propertyChangeListener);
+		this.jcomp.addPropertyChangeListener(this.propertyChangeListener);
 
-		if (this.tree.isEnabled()
-				&& LafWidgetUtilities.hasAutomaticDnDSupport(this.tree))
+		if (this.jcomp.isEnabled()
+				&& LafWidgetUtilities.hasAutomaticDnDSupport(this.jcomp))
 			this.installDnDSupport();
 	}
 
@@ -172,32 +160,32 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 				String name = evt.getPropertyName();
 
 				if (name.equals(JTree.CELL_RENDERER_PROPERTY)) {
-					TreeCellRenderer renderer = TreeDragAndDropWidget.this.tree
+					TreeCellRenderer renderer = TreeDragAndDropWidget.this.jcomp
 							.getCellRenderer();
 					if (!(renderer instanceof DnDCellRendererProxy)) {
 						TreeDragAndDropWidget.this.rendererProxy = new DnDCellRendererProxy(
 								renderer);
-						TreeDragAndDropWidget.this.tree
+						TreeDragAndDropWidget.this.jcomp
 								.setCellRenderer(TreeDragAndDropWidget.this.rendererProxy);
-						TreeDragAndDropWidget.this.tree.repaint();
+						TreeDragAndDropWidget.this.jcomp.repaint();
 					} else
 						TreeDragAndDropWidget.this.rendererProxy = (DnDCellRendererProxy) renderer;
 				}
 			}
 		};
 
-		this.tree.addPropertyChangeListener(this.cellRendererChangeListener);
-		if (this.tree.getCellRenderer() != null) {
-			this.tree.setCellRenderer(new DnDCellRendererProxy(this.tree
+		this.jcomp.addPropertyChangeListener(this.cellRendererChangeListener);
+		if (this.jcomp.getCellRenderer() != null) {
+			this.jcomp.setCellRenderer(new DnDCellRendererProxy(this.jcomp
 					.getCellRenderer()));
 		}
 		this.dragSource = new DragSource();
 		this.gestureListener = new TreeDragGestureListener();
 		this.dragGestureRecognizer = this.dragSource
-				.createDefaultDragGestureRecognizer(this.tree,
+				.createDefaultDragGestureRecognizer(this.jcomp,
 						DnDConstants.ACTION_COPY_OR_MOVE, this.gestureListener);
 		this.dropListener = new TreeDropTargetListener();
-		this.dropTarget = new AutoScrollingTreeDropTarget(this.tree,
+		this.dropTarget = new AutoScrollingTreeDropTarget(this.jcomp,
 				this.dropListener);
 	}
 
@@ -206,8 +194,9 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 	 * 
 	 * @see org.jvnet.lafwidget.LafWidgetAdapter#uninstallListeners()
 	 */
+	@Override
 	public void uninstallListeners() {
-		this.tree.removePropertyChangeListener(this.propertyChangeListener);
+		this.jcomp.removePropertyChangeListener(this.propertyChangeListener);
 		this.propertyChangeListener = null;
 
 		this.uninstallDnDSupport();
@@ -215,22 +204,22 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 
 	private void uninstallDnDSupport() {
 		if (this.cellRendererChangeListener != null) {
-			this.tree
+			this.jcomp
 					.removePropertyChangeListener(this.cellRendererChangeListener);
 			this.cellRendererChangeListener = null;
 		}
 
-		TreeCellRenderer tcl = this.tree.getCellRenderer();
+		TreeCellRenderer tcl = this.jcomp.getCellRenderer();
 		if (tcl instanceof DnDCellRendererProxy) {
 			TreeCellRenderer origRenderer = ((DnDCellRendererProxy) tcl)
 					.getOriginalTreeCellRenderer();
-			this.tree.setCellRenderer(origRenderer);
+			this.jcomp.setCellRenderer(origRenderer);
 		}
 
 		if (this.dropListener != null) {
 			this.dropTarget.removeDropTargetListener(this.dropListener);
 			this.dropListener = null;
-			this.tree.setDropTarget(null);
+			this.jcomp.setDropTarget(null);
 		}
 
 		if (this.dragGestureRecognizer != null) {
@@ -247,11 +236,11 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 	class TreeDragGestureListener implements DragGestureListener {
 		public void dragGestureRecognized(DragGestureEvent dge) {
 			// If tree is disabled then discard drag from it
-			if (!TreeDragAndDropWidget.this.tree.isEnabled())
+			if (!TreeDragAndDropWidget.this.jcomp.isEnabled())
 				return;
 
 			// Select the node that the user is trying to drag, if any.
-			TreePath draggedPath = TreeDragAndDropWidget.this.tree
+			TreePath draggedPath = TreeDragAndDropWidget.this.jcomp
 					.getClosestPathForLocation(dge.getDragOrigin().x, dge
 							.getDragOrigin().y);
 			if (draggedPath == null)
@@ -265,8 +254,8 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 
 			// Prepare the node for transfer
 			TransferableTreeNode transferableNode = new TransferableTreeNode(
-					TreeDragAndDropWidget.this.tree, (MutableTreeNode) node,
-					TreeDragAndDropWidget.this.tree.isExpanded(draggedPath));
+					TreeDragAndDropWidget.this.jcomp, (MutableTreeNode) node,
+					TreeDragAndDropWidget.this.jcomp.isExpanded(draggedPath));
 			TreeDragAndDropWidget.this.rendererProxy.setDraggedNode(node);
 
 			// Initialize the drag. If isDragImageSupported then build a
@@ -276,14 +265,14 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 			// Create an image with the dragged node.
 			TreeCellRenderer renderer = TreeDragAndDropWidget.this.rendererProxy
 					.getOriginalTreeCellRenderer();
-			Rectangle dragBounds = TreeDragAndDropWidget.this.tree
+			Rectangle dragBounds = TreeDragAndDropWidget.this.jcomp
 					.getPathBounds(draggedPath);
 			imageOffset = new Point(dge.getDragOrigin().x - dragBounds.x, dge
 					.getDragOrigin().y
 					- dragBounds.y);
 			Component component = renderer.getTreeCellRendererComponent(
-					TreeDragAndDropWidget.this.tree, node, false,
-					TreeDragAndDropWidget.this.tree.isExpanded(draggedPath),
+					TreeDragAndDropWidget.this.jcomp, node, false,
+					TreeDragAndDropWidget.this.jcomp.isExpanded(draggedPath),
 					node.isLeaf(), 0, false);
 			component.setSize(dragBounds.width, dragBounds.height);
 			image = new BufferedImage(dragBounds.width, dragBounds.height,
@@ -332,11 +321,11 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 
 	class TreeDropTargetListener implements DropTargetListener {
 		public void drop(DropTargetDropEvent dtde) {
-			TreePath dropPath = TreeDragAndDropWidget.this.tree
+			TreePath dropPath = TreeDragAndDropWidget.this.jcomp
 					.getClosestPathForLocation(dtde.getLocation().x, dtde
 							.getLocation().y);
 
-			if (!TreeDragAndDropWidget.this.tree.isEnabled()
+			if (!TreeDragAndDropWidget.this.jcomp.isEnabled()
 					|| (dropPath == null)) {
 				dtde.rejectDrop();
 				dtde.dropComplete(false);
@@ -364,13 +353,13 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 									.dropNodes(
 											ttn.getSourceTree(),
 											ttn.getSourceNode(),
-											TreeDragAndDropWidget.this.tree,
+											TreeDragAndDropWidget.this.jcomp,
 											TreeDragAndDropWidget.this.dropNode,
 											(dtde.getDropAction() & DnDConstants.ACTION_MOVE) != 0));
 					if (ttn.isNodeWasExpanded()) {
-						DefaultTreeModel targetModel = (DefaultTreeModel) TreeDragAndDropWidget.this.tree
+						DefaultTreeModel targetModel = (DefaultTreeModel) TreeDragAndDropWidget.this.jcomp
 								.getModel();
-						TreeDragAndDropWidget.this.tree
+						TreeDragAndDropWidget.this.jcomp
 								.expandPath(new TreePath(targetModel
 										.getPathToRoot(ttn.getSourceNode())));
 					}
@@ -394,7 +383,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 					String droppedString = (String) dtde.getTransferable()
 							.getTransferData(DataFlavor.stringFlavor);
 					if (TreeDragAndDropWidget.this.mayDropHere(droppedString,
-							TreeDragAndDropWidget.this.tree, dropPath)) {
+							TreeDragAndDropWidget.this.jcomp, dropPath)) {
 						dtde.dropComplete(this.dropString(droppedString));
 						TreeDragAndDropWidget.this.resetDragAndDrop();
 					} else {
@@ -424,7 +413,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 
 		private boolean dropString(String droppedString) {
 			// Get the mutable TreeModel
-			DefaultTreeModel model = (DefaultTreeModel) TreeDragAndDropWidget.this.tree
+			DefaultTreeModel model = (DefaultTreeModel) TreeDragAndDropWidget.this.jcomp
 					.getModel();
 
 			// Ask the listeners to handle this drop
@@ -434,7 +423,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 			if ((listeners != null) && (listeners.length > 0)) {
 				try {
 					StringTreeDnDEvent event = new StringTreeDnDEvent(
-							droppedString, TreeDragAndDropWidget.this.tree,
+							droppedString, TreeDragAndDropWidget.this.jcomp,
 							TreeDragAndDropWidget.this.dropNode);
 					for (int i = 0; i < listeners.length; i++) {
 						((StringTreeDnDListener) listeners[i]).drop(event);
@@ -531,7 +520,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 		public void dragExit(DropTargetEvent dte) {
 			TreeDragAndDropWidget.this.dropNode = null;
 			TreeDragAndDropWidget.this.rendererProxy.setDropNode(null);
-			TreeDragAndDropWidget.this.tree.repaint();
+			TreeDragAndDropWidget.this.jcomp.repaint();
 		}
 
 		public void dropActionChanged(DropTargetDragEvent dtde) {
@@ -560,13 +549,13 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 		private TreeNode lastDragOverNode = null;
 
 		public void dragOver(DropTargetDragEvent dtde) {
-			if (!TreeDragAndDropWidget.this.tree.isEnabled()) {
+			if (!TreeDragAndDropWidget.this.jcomp.isEnabled()) {
 				dtde.rejectDrag();
 				return;
 			}
 
 			// Is this a valid node for dropping?
-			TreePath dropPath = TreeDragAndDropWidget.this.tree
+			TreePath dropPath = TreeDragAndDropWidget.this.jcomp
 					.getClosestPathForLocation(dtde.getLocation().x, dtde
 							.getLocation().y);
 
@@ -595,8 +584,8 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 						sourceNode, dropPath)) {
 					TreeDragAndDropWidget.this.dropNode = (MutableTreeNode) dropPath
 							.getLastPathComponent();
-					if (!TreeDragAndDropWidget.this.tree.isExpanded(dropPath))
-						TreeDragAndDropWidget.this.tree.expandPath(dropPath);
+					if (!TreeDragAndDropWidget.this.jcomp.isExpanded(dropPath))
+						TreeDragAndDropWidget.this.jcomp.expandPath(dropPath);
 					mayDropHere = true;
 				} else {
 					TreeDragAndDropWidget.this.dropNode = null;
@@ -608,12 +597,12 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 					String sourceText = (String) transferable
 							.getTransferData(DataFlavor.stringFlavor);
 					if (TreeDragAndDropWidget.this.mayDropHere(sourceText,
-							TreeDragAndDropWidget.this.tree, dropPath)) {
+							TreeDragAndDropWidget.this.jcomp, dropPath)) {
 						TreeDragAndDropWidget.this.dropNode = (MutableTreeNode) dropPath
 								.getLastPathComponent();
-						if (!TreeDragAndDropWidget.this.tree
+						if (!TreeDragAndDropWidget.this.jcomp
 								.isExpanded(dropPath))
-							TreeDragAndDropWidget.this.tree
+							TreeDragAndDropWidget.this.jcomp
 									.expandPath(dropPath);
 						mayDropHere = true;
 					} else {
@@ -636,13 +625,13 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 					.setDropAllowed(mayDropHere);
 			TreeDragAndDropWidget.this.rendererProxy
 					.setDropNode((TreeNode) dropPath.getLastPathComponent());
-			TreeDragAndDropWidget.this.tree.repaint();
+			TreeDragAndDropWidget.this.jcomp.repaint();
 			if (!mayDropHere) {
 				dtde.rejectDrag();
 			} else {
 				dtde.acceptDrag(dtde.getDropAction());
 			}
-			TreeDragAndDropWidget.this.tree.repaint();
+			TreeDragAndDropWidget.this.jcomp.repaint();
 		}
 
 		public void dragEnter(DropTargetDragEvent dtde) {
@@ -731,8 +720,8 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 		boolean mayDropHere = (aNode != aSourceNode)
 				&& (aNode instanceof MutableTreeNode)
 				&& ((aNode.getParent() == null) || (aNode.getParent() instanceof MutableTreeNode))
-				&& (this.tree.getModel() instanceof DefaultTreeModel)
-				&& !((this.tree == aSourceTree) && TreeDragAndDropWidget
+				&& (this.jcomp.getModel() instanceof DefaultTreeModel)
+				&& !((this.jcomp == aSourceTree) && TreeDragAndDropWidget
 						.isAncestorOf(aSourceNode, aNode));
 
 		if (mayDropHere) {
@@ -742,7 +731,7 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 			if ((listeners != null) && (listeners.length > 0)) {
 				try {
 					TreeTreeDnDEvent event = new TreeTreeDnDEvent(aSourceTree,
-							aSourceNode, this.tree, aNode);
+							aSourceNode, this.jcomp, aNode);
 					for (int i = 0; i < listeners.length; i++) {
 						((TreeTreeDnDListener) listeners[i]).mayDrop(event);
 					}
@@ -773,6 +762,6 @@ public class TreeDragAndDropWidget extends LafWidgetAdapter {
 		this.rendererProxy.setDraggedNode(null);
 		this.rendererProxy.setDropAllowed(false);
 		this.rendererProxy.setDropNode(null);
-		this.tree.repaint();
+		this.jcomp.repaint();
 	}
 }
